# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: app_socket.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import common_model_pb2 as common__model__pb2
from . import app_model_pb2 as app__model__pb2
from . import identity_state_pb2 as identity__state__pb2
from . import messaging_model_pb2 as messaging__model__pb2
from . import messaging_state_pb2 as messaging__state__pb2
from . import payment_model_pb2 as payment__model__pb2
from . import payment_state_pb2 as payment__state__pb2
from . import activity_state_pb2 as activity__state__pb2
from . import activity_model_pb2 as activity__model__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='app_socket.proto',
  package='com.elarian.hera.proto',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x10\x61pp_socket.proto\x12\x16\x63om.elarian.hera.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x12\x63ommon_model.proto\x1a\x0f\x61pp_model.proto\x1a\x14identity_state.proto\x1a\x15messaging_model.proto\x1a\x15messaging_state.proto\x1a\x13payment_model.proto\x1a\x13payment_state.proto\x1a\x14\x61\x63tivity_state.proto\x1a\x14\x61\x63tivity_model.proto\"\xc6\x01\n\x15\x41ppConnectionMetadata\x12\x0e\n\x06org_id\x18\x01 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\t\x12-\n\x07\x61pi_key\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x30\n\nauth_token\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x14\n\x0csimplex_mode\x18\x05 \x01(\x08\x12\x16\n\x0esimulator_mode\x18\x06 \x01(\x08\"\xf5\x0e\n\x12\x41ppToServerCommand\x12O\n\x13generate_auth_token\x18\x01 \x01(\x0b\x32\x30.com.elarian.hera.proto.GenerateAuthTokenCommandH\x00\x12M\n\x12get_customer_state\x18\x02 \x01(\x0b\x32/.com.elarian.hera.proto.GetCustomerStateCommandH\x00\x12Q\n\x14\x61\x64opt_customer_state\x18\x03 \x01(\x0b\x32\x31.com.elarian.hera.proto.AdoptCustomerStateCommandH\x00\x12S\n\x15\x61\x64\x64_customer_reminder\x18\x04 \x01(\x0b\x32\x32.com.elarian.hera.proto.AddCustomerReminderCommandH\x00\x12Z\n\x19\x61\x64\x64_customer_reminder_tag\x18\x05 \x01(\x0b\x32\x35.com.elarian.hera.proto.AddCustomerReminderTagCommandH\x00\x12Y\n\x18\x63\x61ncel_customer_reminder\x18\x06 \x01(\x0b\x32\x35.com.elarian.hera.proto.CancelCustomerReminderCommandH\x00\x12`\n\x1c\x63\x61ncel_customer_reminder_tag\x18\x07 \x01(\x0b\x32\x38.com.elarian.hera.proto.CancelCustomerReminderTagCommandH\x00\x12O\n\x13update_customer_tag\x18\x08 \x01(\x0b\x32\x30.com.elarian.hera.proto.UpdateCustomerTagCommandH\x00\x12O\n\x13\x64\x65lete_customer_tag\x18\t \x01(\x0b\x32\x30.com.elarian.hera.proto.DeleteCustomerTagCommandH\x00\x12`\n\x1cupdate_customer_secondary_id\x18\n \x01(\x0b\x32\x38.com.elarian.hera.proto.UpdateCustomerSecondaryIdCommandH\x00\x12`\n\x1c\x64\x65lete_customer_secondary_id\x18\x0b \x01(\x0b\x32\x38.com.elarian.hera.proto.DeleteCustomerSecondaryIdCommandH\x00\x12Y\n\x18update_customer_metadata\x18\x0c \x01(\x0b\x32\x35.com.elarian.hera.proto.UpdateCustomerMetadataCommandH\x00\x12Y\n\x18\x64\x65lete_customer_metadata\x18\r \x01(\x0b\x32\x35.com.elarian.hera.proto.DeleteCustomerMetadataCommandH\x00\x12V\n\x17lease_customer_app_data\x18\x0e \x01(\x0b\x32\x33.com.elarian.hera.proto.LeaseCustomerAppDataCommandH\x00\x12X\n\x18update_customer_app_data\x18\x0f \x01(\x0b\x32\x34.com.elarian.hera.proto.UpdateCustomerAppDataCommandH\x00\x12X\n\x18\x64\x65lete_customer_app_data\x18\x10 \x01(\x0b\x32\x34.com.elarian.hera.proto.DeleteCustomerAppDataCommandH\x00\x12\x42\n\x0csend_message\x18\x11 \x01(\x0b\x32*.com.elarian.hera.proto.SendMessageCommandH\x00\x12I\n\x10send_message_tag\x18\x12 \x01(\x0b\x32-.com.elarian.hera.proto.SendMessageTagCommandH\x00\x12I\n\x10reply_to_message\x18\x13 \x01(\x0b\x32-.com.elarian.hera.proto.ReplyToMessageCommandH\x00\x12Y\n\x18update_messaging_consent\x18\x14 \x01(\x0b\x32\x35.com.elarian.hera.proto.UpdateMessagingConsentCommandH\x00\x12J\n\x10initiate_payment\x18\x15 \x01(\x0b\x32..com.elarian.hera.proto.InitiatePaymentCommandH\x00\x12L\n\x11\x63ustomer_activity\x18\x16 \x01(\x0b\x32/.com.elarian.hera.proto.CustomerActivityCommandH\x00\x42\x07\n\x05\x65ntry\"\xb0\x06\n\x17\x41ppToServerCommandReply\x12M\n\x13generate_auth_token\x18\x01 \x01(\x0b\x32..com.elarian.hera.proto.GenerateAuthTokenReplyH\x00\x12K\n\x12get_customer_state\x18\x02 \x01(\x0b\x32-.com.elarian.hera.proto.GetCustomerStateReplyH\x00\x12Q\n\x15update_customer_state\x18\x03 \x01(\x0b\x32\x30.com.elarian.hera.proto.UpdateCustomerStateReplyH\x00\x12V\n\x18update_customer_app_data\x18\x04 \x01(\x0b\x32\x32.com.elarian.hera.proto.UpdateCustomerAppDataReplyH\x00\x12T\n\x17lease_customer_app_data\x18\x05 \x01(\x0b\x32\x31.com.elarian.hera.proto.LeaseCustomerAppDataReplyH\x00\x12@\n\x0csend_message\x18\x06 \x01(\x0b\x32(.com.elarian.hera.proto.SendMessageReplyH\x00\x12W\n\x18update_messaging_consent\x18\x07 \x01(\x0b\x32\x33.com.elarian.hera.proto.UpdateMessagingConsentReplyH\x00\x12H\n\x10initiate_payment\x18\x08 \x01(\x0b\x32,.com.elarian.hera.proto.InitiatePaymentReplyH\x00\x12>\n\x0btag_command\x18\t \x01(\x0b\x32\'.com.elarian.hera.proto.TagCommandReplyH\x00\x12J\n\x11\x63ustomer_activity\x18\n \x01(\x0b\x32-.com.elarian.hera.proto.CustomerActivityReplyH\x00\x42\x07\n\x05\x65ntry\"\x1a\n\x18GenerateAuthTokenCommand\"T\n\x16GenerateAuthTokenReply\x12\r\n\x05token\x18\x01 \x01(\t\x12+\n\x08lifetime\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\"\xbd\x01\n\x17GetCustomerStateCommand\x12\x15\n\x0b\x63ustomer_id\x18\x01 \x01(\tH\x00\x12\x41\n\x0f\x63ustomer_number\x18\x02 \x01(\x0b\x32&.com.elarian.hera.proto.CustomerNumberH\x00\x12<\n\x0csecondary_id\x18\x03 \x01(\x0b\x32$.com.elarian.hera.proto.IndexMappingH\x00\x42\n\n\x08\x63ustomer\"z\n\x15GetCustomerStateReply\x12\x0e\n\x06status\x18\x01 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12<\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32..com.elarian.hera.proto.CustomerStateReplyData\"\xa9\x02\n\x16\x43ustomerStateReplyData\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12=\n\x0eidentity_state\x18\x02 \x01(\x0b\x32%.com.elarian.hera.proto.IdentityState\x12?\n\x0fmessaging_state\x18\x03 \x01(\x0b\x32&.com.elarian.hera.proto.MessagingState\x12;\n\rpayment_state\x18\x04 \x01(\x0b\x32$.com.elarian.hera.proto.PaymentState\x12=\n\x0e\x61\x63tivity_state\x18\x05 \x01(\x0b\x32%.com.elarian.hera.proto.ActivityState\"\xec\x01\n\x19\x41\x64optCustomerStateCommand\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12\x1b\n\x11other_customer_id\x18\x02 \x01(\tH\x00\x12G\n\x15other_customer_number\x18\x03 \x01(\x0b\x32&.com.elarian.hera.proto.CustomerNumberH\x00\x12\x42\n\x12other_secondary_id\x18\x04 \x01(\x0b\x32$.com.elarian.hera.proto.IndexMappingH\x00\x42\x10\n\x0eother_customer\"\xfc\x01\n\x1a\x41\x64\x64\x43ustomerReminderCommand\x12\x15\n\x0b\x63ustomer_id\x18\x01 \x01(\tH\x00\x12\x41\n\x0f\x63ustomer_number\x18\x02 \x01(\x0b\x32&.com.elarian.hera.proto.CustomerNumberH\x00\x12<\n\x0csecondary_id\x18\x03 \x01(\x0b\x32$.com.elarian.hera.proto.IndexMappingH\x00\x12:\n\x08reminder\x18\x04 \x01(\x0b\x32(.com.elarian.hera.proto.CustomerReminderB\n\n\x08\x63ustomer\"\x8e\x01\n\x1d\x41\x64\x64\x43ustomerReminderTagCommand\x12\x31\n\x03tag\x18\x01 \x01(\x0b\x32$.com.elarian.hera.proto.IndexMapping\x12:\n\x08reminder\x18\x02 \x01(\x0b\x32(.com.elarian.hera.proto.CustomerReminder\"\xd0\x01\n\x1d\x43\x61ncelCustomerReminderCommand\x12\x15\n\x0b\x63ustomer_id\x18\x01 \x01(\tH\x00\x12\x41\n\x0f\x63ustomer_number\x18\x02 \x01(\x0b\x32&.com.elarian.hera.proto.CustomerNumberH\x00\x12<\n\x0csecondary_id\x18\x03 \x01(\x0b\x32$.com.elarian.hera.proto.IndexMappingH\x00\x12\x0b\n\x03key\x18\x04 \x01(\tB\n\n\x08\x63ustomer\"b\n CancelCustomerReminderTagCommand\x12\x31\n\x03tag\x18\x01 \x01(\x0b\x32$.com.elarian.hera.proto.IndexMapping\x12\x0b\n\x03key\x18\x02 \x01(\t\"\xf6\x01\n\x18UpdateCustomerTagCommand\x12\x15\n\x0b\x63ustomer_id\x18\x01 \x01(\tH\x00\x12\x41\n\x0f\x63ustomer_number\x18\x02 \x01(\x0b\x32&.com.elarian.hera.proto.CustomerNumberH\x00\x12<\n\x0csecondary_id\x18\x03 \x01(\x0b\x32$.com.elarian.hera.proto.IndexMappingH\x00\x12\x36\n\x07updates\x18\x04 \x03(\x0b\x32%.com.elarian.hera.proto.CustomerIndexB\n\n\x08\x63ustomer\"\xd1\x01\n\x18\x44\x65leteCustomerTagCommand\x12\x15\n\x0b\x63ustomer_id\x18\x01 \x01(\tH\x00\x12\x41\n\x0f\x63ustomer_number\x18\x02 \x01(\x0b\x32&.com.elarian.hera.proto.CustomerNumberH\x00\x12<\n\x0csecondary_id\x18\x03 \x01(\x0b\x32$.com.elarian.hera.proto.IndexMappingH\x00\x12\x11\n\tdeletions\x18\x04 \x03(\tB\n\n\x08\x63ustomer\"\xfe\x01\n UpdateCustomerSecondaryIdCommand\x12\x15\n\x0b\x63ustomer_id\x18\x01 \x01(\tH\x00\x12\x41\n\x0f\x63ustomer_number\x18\x02 \x01(\x0b\x32&.com.elarian.hera.proto.CustomerNumberH\x00\x12<\n\x0csecondary_id\x18\x03 \x01(\x0b\x32$.com.elarian.hera.proto.IndexMappingH\x00\x12\x36\n\x07updates\x18\x04 \x03(\x0b\x32%.com.elarian.hera.proto.CustomerIndexB\n\n\x08\x63ustomer\"\xff\x01\n DeleteCustomerSecondaryIdCommand\x12\x15\n\x0b\x63ustomer_id\x18\x01 \x01(\tH\x00\x12\x41\n\x0f\x63ustomer_number\x18\x02 \x01(\x0b\x32&.com.elarian.hera.proto.CustomerNumberH\x00\x12<\n\x0csecondary_id\x18\x03 \x01(\x0b\x32$.com.elarian.hera.proto.IndexMappingH\x00\x12\x37\n\tdeletions\x18\x04 \x03(\x0b\x32$.com.elarian.hera.proto.IndexMappingB\n\n\x08\x63ustomer\"\xee\x02\n\x1dUpdateCustomerMetadataCommand\x12\x15\n\x0b\x63ustomer_id\x18\x01 \x01(\tH\x00\x12\x41\n\x0f\x63ustomer_number\x18\x02 \x01(\x0b\x32&.com.elarian.hera.proto.CustomerNumberH\x00\x12<\n\x0csecondary_id\x18\x03 \x01(\x0b\x32$.com.elarian.hera.proto.IndexMappingH\x00\x12S\n\x07updates\x18\x04 \x03(\x0b\x32\x42.com.elarian.hera.proto.UpdateCustomerMetadataCommand.UpdatesEntry\x1aT\n\x0cUpdatesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x33\n\x05value\x18\x02 \x01(\x0b\x32$.com.elarian.hera.proto.DataMapValue:\x02\x38\x01\x42\n\n\x08\x63ustomer\"\xd6\x01\n\x1d\x44\x65leteCustomerMetadataCommand\x12\x15\n\x0b\x63ustomer_id\x18\x01 \x01(\tH\x00\x12\x41\n\x0f\x63ustomer_number\x18\x02 \x01(\x0b\x32&.com.elarian.hera.proto.CustomerNumberH\x00\x12<\n\x0csecondary_id\x18\x03 \x01(\x0b\x32$.com.elarian.hera.proto.IndexMappingH\x00\x12\x11\n\tdeletions\x18\x04 \x03(\tB\n\n\x08\x63ustomer\"r\n\x18UpdateCustomerStateReply\x12\x0e\n\x06status\x18\x01 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x31\n\x0b\x63ustomer_id\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xf8\x01\n\x1cUpdateCustomerAppDataCommand\x12\x15\n\x0b\x63ustomer_id\x18\x01 \x01(\tH\x00\x12\x41\n\x0f\x63ustomer_number\x18\x02 \x01(\x0b\x32&.com.elarian.hera.proto.CustomerNumberH\x00\x12<\n\x0csecondary_id\x18\x03 \x01(\x0b\x32$.com.elarian.hera.proto.IndexMappingH\x00\x12\x34\n\x06update\x18\x04 \x01(\x0b\x32$.com.elarian.hera.proto.DataMapValueB\n\n\x08\x63ustomer\"\xc2\x01\n\x1c\x44\x65leteCustomerAppDataCommand\x12\x15\n\x0b\x63ustomer_id\x18\x01 \x01(\tH\x00\x12\x41\n\x0f\x63ustomer_number\x18\x02 \x01(\x0b\x32&.com.elarian.hera.proto.CustomerNumberH\x00\x12<\n\x0csecondary_id\x18\x03 \x01(\x0b\x32$.com.elarian.hera.proto.IndexMappingH\x00\x42\n\n\x08\x63ustomer\"t\n\x1aUpdateCustomerAppDataReply\x12\x0e\n\x06status\x18\x01 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x31\n\x0b\x63ustomer_id\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xc1\x01\n\x1bLeaseCustomerAppDataCommand\x12\x15\n\x0b\x63ustomer_id\x18\x01 \x01(\tH\x00\x12\x41\n\x0f\x63ustomer_number\x18\x02 \x01(\x0b\x32&.com.elarian.hera.proto.CustomerNumberH\x00\x12<\n\x0csecondary_id\x18\x03 \x01(\x0b\x32$.com.elarian.hera.proto.IndexMappingH\x00\x42\n\n\x08\x63ustomer\"\xa8\x01\n\x19LeaseCustomerAppDataReply\x12\x0e\n\x06status\x18\x01 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x31\n\x0b\x63ustomer_id\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\x05value\x18\x04 \x01(\x0b\x32$.com.elarian.hera.proto.DataMapValue\"\xd7\x01\n\x12SendMessageCommand\x12?\n\x0f\x63ustomer_number\x18\x01 \x01(\x0b\x32&.com.elarian.hera.proto.CustomerNumber\x12\x46\n\x0e\x63hannel_number\x18\x02 \x01(\x0b\x32..com.elarian.hera.proto.MessagingChannelNumber\x12\x38\n\x07message\x18\x03 \x01(\x0b\x32\'.com.elarian.hera.proto.OutboundMessage\"z\n\x15ReplyToMessageCommand\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12\x12\n\nmessage_id\x18\x02 \x01(\t\x12\x38\n\x07message\x18\x03 \x01(\x0b\x32\'.com.elarian.hera.proto.OutboundMessage\"\xcc\x01\n\x15SendMessageTagCommand\x12\x31\n\x03tag\x18\x01 \x01(\x0b\x32$.com.elarian.hera.proto.IndexMapping\x12\x46\n\x0e\x63hannel_number\x18\x02 \x01(\x0b\x32..com.elarian.hera.proto.MessagingChannelNumber\x12\x38\n\x07message\x18\x03 \x01(\x0b\x32\'.com.elarian.hera.proto.OutboundMessage\"\xfd\x01\n\x10SendMessageReply\x12=\n\x06status\x18\x01 \x01(\x0e\x32-.com.elarian.hera.proto.MessageDeliveryStatus\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x30\n\nmessage_id\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x30\n\nsession_id\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0b\x63ustomer_id\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xe8\x01\n\x1dUpdateMessagingConsentCommand\x12?\n\x0f\x63ustomer_number\x18\x01 \x01(\x0b\x32&.com.elarian.hera.proto.CustomerNumber\x12\x46\n\x0e\x63hannel_number\x18\x02 \x01(\x0b\x32..com.elarian.hera.proto.MessagingChannelNumber\x12>\n\x06update\x18\x03 \x01(\x0e\x32..com.elarian.hera.proto.MessagingConsentUpdate\"\xab\x01\n\x1bUpdateMessagingConsentReply\x12\x44\n\x06status\x18\x01 \x01(\x0e\x32\x34.com.elarian.hera.proto.MessagingConsentUpdateStatus\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x31\n\x0b\x63ustomer_id\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xca\x01\n\x16InitiatePaymentCommand\x12@\n\x0b\x64\x65\x62it_party\x18\x01 \x01(\x0b\x32+.com.elarian.hera.proto.PaymentCounterParty\x12\x41\n\x0c\x63redit_party\x18\x02 \x01(\x0b\x32+.com.elarian.hera.proto.PaymentCounterParty\x12+\n\x05value\x18\x03 \x01(\x0b\x32\x1c.com.elarian.hera.proto.Cash\"\x8b\x02\n\x14InitiatePaymentReply\x12\x35\n\x06status\x18\x01 \x01(\x0e\x32%.com.elarian.hera.proto.PaymentStatus\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x34\n\x0etransaction_id\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x37\n\x11\x64\x65\x62it_customer_id\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x38\n\x12\x63redit_customer_id\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"e\n\x0fTagCommandReply\x12\x0e\n\x06status\x18\x01 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12-\n\x07work_id\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xca\x02\n\x17\x43ustomerActivityCommand\x12?\n\x0f\x63ustomer_number\x18\x01 \x01(\x0b\x32&.com.elarian.hera.proto.CustomerNumber\x12\x45\n\x0e\x63hannel_number\x18\x02 \x01(\x0b\x32-.com.elarian.hera.proto.ActivityChannelNumber\x12\x12\n\nsession_id\x18\x03 \x01(\t\x12\x0b\n\x03key\x18\x04 \x01(\t\x12S\n\nproperties\x18\x05 \x03(\x0b\x32?.com.elarian.hera.proto.CustomerActivityCommand.PropertiesEntry\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"o\n\x15\x43ustomerActivityReply\x12\x0e\n\x06status\x18\x01 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x31\n\x0b\x63ustomer_id\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xb6\x01\n\x17ServerToAppNotification\x12K\n\x08\x63ustomer\x18\x01 \x01(\x0b\x32\x37.com.elarian.hera.proto.ServerToAppCustomerNotificationH\x00\x12\x45\n\x05purse\x18\x02 \x01(\x0b\x32\x34.com.elarian.hera.proto.ServerToAppPurseNotificationH\x00\x42\x07\n\x05\x65ntry\"\xce\t\n\x1fServerToAppCustomerNotification\x12\x0e\n\x06org_id\x18\x01 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\t\x12\x13\n\x0b\x63ustomer_id\x18\x03 \x01(\t\x12\x36\n\x08\x61pp_data\x18\x04 \x01(\x0b\x32$.com.elarian.hera.proto.DataMapValue\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12@\n\x08reminder\x18\x06 \x01(\x0b\x32,.com.elarian.hera.proto.ReminderNotificationH\x00\x12`\n\x19messaging_session_started\x18\x07 \x01(\x0b\x32;.com.elarian.hera.proto.MessagingSessionStartedNotificationH\x00\x12`\n\x19messaging_session_renewed\x18\x08 \x01(\x0b\x32;.com.elarian.hera.proto.MessagingSessionRenewedNotificationH\x00\x12\\\n\x17messaging_session_ended\x18\t \x01(\x0b\x32\x39.com.elarian.hera.proto.MessagingSessionEndedNotificationH\x00\x12^\n\x18messaging_consent_update\x18\n \x01(\x0b\x32:.com.elarian.hera.proto.MessagingConsentUpdateNotificationH\x00\x12O\n\x10received_message\x18\x0b \x01(\x0b\x32\x33.com.elarian.hera.proto.ReceivedMessageNotificationH\x00\x12K\n\x0emessage_status\x18\x0c \x01(\x0b\x32\x31.com.elarian.hera.proto.MessageStatusNotificationH\x00\x12X\n\x15sent_message_reaction\x18\r \x01(\x0b\x32\x37.com.elarian.hera.proto.SentMessageReactionNotificationH\x00\x12O\n\x10received_payment\x18\x0e \x01(\x0b\x32\x33.com.elarian.hera.proto.ReceivedPaymentNotificationH\x00\x12K\n\x0epayment_status\x18\x0f \x01(\x0b\x32\x31.com.elarian.hera.proto.PaymentStatusNotificationH\x00\x12X\n\x15wallet_payment_status\x18\x10 \x01(\x0b\x32\x37.com.elarian.hera.proto.WalletPaymentStatusNotificationH\x00\x12Q\n\x11\x63ustomer_activity\x18\x11 \x01(\x0b\x32\x34.com.elarian.hera.proto.CustomerActivityNotificationH\x00\x42\x07\n\x05\x65ntry\"\xd6\x01\n\x1cServerToAppPurseNotification\x12\x0e\n\x06org_id\x18\x01 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\t\x12\x10\n\x08purse_id\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12K\n\x0epayment_status\x18\x05 \x01(\x0b\x32\x31.com.elarian.hera.proto.PaymentStatusNotificationH\x00\x42\x07\n\x05\x65ntry\"C\n\rAppDataUpdate\x12\x32\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32$.com.elarian.hera.proto.DataMapValue\"\x94\x01\n\x1cServerToAppNotificationReply\x12:\n\x0b\x64\x61ta_update\x18\x01 \x01(\x0b\x32%.com.elarian.hera.proto.AppDataUpdate\x12\x38\n\x07message\x18\x02 \x01(\x0b\x32\'.com.elarian.hera.proto.OutboundMessage\"\xb5\x01\n\x14ReminderNotification\x12:\n\x08reminder\x18\x01 \x01(\x0b\x32(.com.elarian.hera.proto.CustomerReminder\x12\x32\n\x03tag\x18\x02 \x01(\x0b\x32%.com.elarian.hera.proto.CustomerIndex\x12-\n\x07work_id\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xf2\x01\n#MessagingSessionStartedNotification\x12?\n\x0f\x63ustomer_number\x18\x01 \x01(\x0b\x32&.com.elarian.hera.proto.CustomerNumber\x12\x46\n\x0e\x63hannel_number\x18\x02 \x01(\x0b\x32..com.elarian.hera.proto.MessagingChannelNumber\x12\x12\n\nsession_id\x18\x03 \x01(\t\x12.\n\nexpires_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xf2\x01\n#MessagingSessionRenewedNotification\x12?\n\x0f\x63ustomer_number\x18\x01 \x01(\x0b\x32&.com.elarian.hera.proto.CustomerNumber\x12\x46\n\x0e\x63hannel_number\x18\x02 \x01(\x0b\x32..com.elarian.hera.proto.MessagingChannelNumber\x12\x12\n\nsession_id\x18\x03 \x01(\t\x12.\n\nexpires_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xb0\x02\n!MessagingSessionEndedNotification\x12?\n\x0f\x63ustomer_number\x18\x01 \x01(\x0b\x32&.com.elarian.hera.proto.CustomerNumber\x12\x46\n\x0e\x63hannel_number\x18\x02 \x01(\x0b\x32..com.elarian.hera.proto.MessagingChannelNumber\x12\x12\n\nsession_id\x18\x03 \x01(\t\x12+\n\x08\x64uration\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x41\n\x06reason\x18\x05 \x01(\x0e\x32\x31.com.elarian.hera.proto.MessagingSessionEndReason\"\xb3\x02\n\"MessagingConsentUpdateNotification\x12?\n\x0f\x63ustomer_number\x18\x01 \x01(\x0b\x32&.com.elarian.hera.proto.CustomerNumber\x12\x46\n\x0e\x63hannel_number\x18\x02 \x01(\x0b\x32..com.elarian.hera.proto.MessagingChannelNumber\x12>\n\x06update\x18\x03 \x01(\x0e\x32..com.elarian.hera.proto.MessagingConsentUpdate\x12\x44\n\x06status\x18\x04 \x01(\x0e\x32\x34.com.elarian.hera.proto.MessagingConsentUpdateStatus\"\xda\x02\n\x1bReceivedMessageNotification\x12\x12\n\nmessage_id\x18\x01 \x01(\t\x12?\n\x0f\x63ustomer_number\x18\x02 \x01(\x0b\x32&.com.elarian.hera.proto.CustomerNumber\x12\x46\n\x0e\x63hannel_number\x18\x03 \x01(\x0b\x32..com.elarian.hera.proto.MessagingChannelNumber\x12\x39\n\x05parts\x18\x04 \x03(\x0b\x32*.com.elarian.hera.proto.InboundMessageBody\x12\x30\n\nsession_id\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0bin_reply_to\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"n\n\x19MessageStatusNotification\x12\x12\n\nmessage_id\x18\x01 \x01(\t\x12=\n\x06status\x18\x02 \x01(\x0e\x32-.com.elarian.hera.proto.MessageDeliveryStatus\"\xf9\x01\n\x1fSentMessageReactionNotification\x12\x12\n\nmessage_id\x18\x01 \x01(\t\x12?\n\x0f\x63ustomer_number\x18\x02 \x01(\x0b\x32&.com.elarian.hera.proto.CustomerNumber\x12\x46\n\x0e\x63hannel_number\x18\x03 \x01(\x0b\x32..com.elarian.hera.proto.MessagingChannelNumber\x12\x39\n\x08reaction\x18\x04 \x01(\x0e\x32\'.com.elarian.hera.proto.MessageReaction\"\xb2\x02\n\x1bReceivedPaymentNotification\x12\x10\n\x08purse_id\x18\x01 \x01(\t\x12\x16\n\x0etransaction_id\x18\x02 \x01(\t\x12?\n\x0f\x63ustomer_number\x18\x03 \x01(\x0b\x32&.com.elarian.hera.proto.CustomerNumber\x12\x44\n\x0e\x63hannel_number\x18\x04 \x01(\x0b\x32,.com.elarian.hera.proto.PaymentChannelNumber\x12+\n\x05value\x18\x05 \x01(\x0b\x32\x1c.com.elarian.hera.proto.Cash\x12\x35\n\x06status\x18\x06 \x01(\x0e\x32%.com.elarian.hera.proto.PaymentStatus\"j\n\x19PaymentStatusNotification\x12\x16\n\x0etransaction_id\x18\x01 \x01(\t\x12\x35\n\x06status\x18\x02 \x01(\x0e\x32%.com.elarian.hera.proto.PaymentStatus\"\x83\x01\n\x1fWalletPaymentStatusNotification\x12\x11\n\twallet_id\x18\x01 \x01(\t\x12\x16\n\x0etransaction_id\x18\x02 \x01(\t\x12\x35\n\x06status\x18\x03 \x01(\x0e\x32%.com.elarian.hera.proto.PaymentStatus\"\xf6\x01\n\x1c\x43ustomerActivityNotification\x12?\n\x0f\x63ustomer_number\x18\x01 \x01(\x0b\x32&.com.elarian.hera.proto.CustomerNumber\x12\x45\n\x0e\x63hannel_number\x18\x02 \x01(\x0b\x32-.com.elarian.hera.proto.ActivityChannelNumber\x12\x12\n\nsession_id\x18\x03 \x01(\t\x12:\n\x08\x61\x63tivity\x18\x04 \x01(\x0b\x32(.com.elarian.hera.proto.CustomerActivityb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,common__model__pb2.DESCRIPTOR,app__model__pb2.DESCRIPTOR,identity__state__pb2.DESCRIPTOR,messaging__model__pb2.DESCRIPTOR,messaging__state__pb2.DESCRIPTOR,payment__model__pb2.DESCRIPTOR,payment__state__pb2.DESCRIPTOR,activity__state__pb2.DESCRIPTOR,activity__model__pb2.DESCRIPTOR,])




_APPCONNECTIONMETADATA = _descriptor.Descriptor(
  name='AppConnectionMetadata',
  full_name='com.elarian.hera.proto.AppConnectionMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='org_id', full_name='com.elarian.hera.proto.AppConnectionMetadata.org_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='com.elarian.hera.proto.AppConnectionMetadata.app_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='api_key', full_name='com.elarian.hera.proto.AppConnectionMetadata.api_key', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth_token', full_name='com.elarian.hera.proto.AppConnectionMetadata.auth_token', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='simplex_mode', full_name='com.elarian.hera.proto.AppConnectionMetadata.simplex_mode', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='simulator_mode', full_name='com.elarian.hera.proto.AppConnectionMetadata.simulator_mode', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=333,
  serialized_end=531,
)


_APPTOSERVERCOMMAND = _descriptor.Descriptor(
  name='AppToServerCommand',
  full_name='com.elarian.hera.proto.AppToServerCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='generate_auth_token', full_name='com.elarian.hera.proto.AppToServerCommand.generate_auth_token', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='get_customer_state', full_name='com.elarian.hera.proto.AppToServerCommand.get_customer_state', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adopt_customer_state', full_name='com.elarian.hera.proto.AppToServerCommand.adopt_customer_state', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='add_customer_reminder', full_name='com.elarian.hera.proto.AppToServerCommand.add_customer_reminder', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='add_customer_reminder_tag', full_name='com.elarian.hera.proto.AppToServerCommand.add_customer_reminder_tag', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cancel_customer_reminder', full_name='com.elarian.hera.proto.AppToServerCommand.cancel_customer_reminder', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cancel_customer_reminder_tag', full_name='com.elarian.hera.proto.AppToServerCommand.cancel_customer_reminder_tag', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_customer_tag', full_name='com.elarian.hera.proto.AppToServerCommand.update_customer_tag', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delete_customer_tag', full_name='com.elarian.hera.proto.AppToServerCommand.delete_customer_tag', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_customer_secondary_id', full_name='com.elarian.hera.proto.AppToServerCommand.update_customer_secondary_id', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delete_customer_secondary_id', full_name='com.elarian.hera.proto.AppToServerCommand.delete_customer_secondary_id', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_customer_metadata', full_name='com.elarian.hera.proto.AppToServerCommand.update_customer_metadata', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delete_customer_metadata', full_name='com.elarian.hera.proto.AppToServerCommand.delete_customer_metadata', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lease_customer_app_data', full_name='com.elarian.hera.proto.AppToServerCommand.lease_customer_app_data', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_customer_app_data', full_name='com.elarian.hera.proto.AppToServerCommand.update_customer_app_data', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delete_customer_app_data', full_name='com.elarian.hera.proto.AppToServerCommand.delete_customer_app_data', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='send_message', full_name='com.elarian.hera.proto.AppToServerCommand.send_message', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='send_message_tag', full_name='com.elarian.hera.proto.AppToServerCommand.send_message_tag', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reply_to_message', full_name='com.elarian.hera.proto.AppToServerCommand.reply_to_message', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_messaging_consent', full_name='com.elarian.hera.proto.AppToServerCommand.update_messaging_consent', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initiate_payment', full_name='com.elarian.hera.proto.AppToServerCommand.initiate_payment', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_activity', full_name='com.elarian.hera.proto.AppToServerCommand.customer_activity', index=21,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='entry', full_name='com.elarian.hera.proto.AppToServerCommand.entry',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=534,
  serialized_end=2443,
)


_APPTOSERVERCOMMANDREPLY = _descriptor.Descriptor(
  name='AppToServerCommandReply',
  full_name='com.elarian.hera.proto.AppToServerCommandReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='generate_auth_token', full_name='com.elarian.hera.proto.AppToServerCommandReply.generate_auth_token', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='get_customer_state', full_name='com.elarian.hera.proto.AppToServerCommandReply.get_customer_state', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_customer_state', full_name='com.elarian.hera.proto.AppToServerCommandReply.update_customer_state', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_customer_app_data', full_name='com.elarian.hera.proto.AppToServerCommandReply.update_customer_app_data', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lease_customer_app_data', full_name='com.elarian.hera.proto.AppToServerCommandReply.lease_customer_app_data', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='send_message', full_name='com.elarian.hera.proto.AppToServerCommandReply.send_message', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_messaging_consent', full_name='com.elarian.hera.proto.AppToServerCommandReply.update_messaging_consent', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initiate_payment', full_name='com.elarian.hera.proto.AppToServerCommandReply.initiate_payment', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tag_command', full_name='com.elarian.hera.proto.AppToServerCommandReply.tag_command', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_activity', full_name='com.elarian.hera.proto.AppToServerCommandReply.customer_activity', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='entry', full_name='com.elarian.hera.proto.AppToServerCommandReply.entry',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2446,
  serialized_end=3262,
)


_GENERATEAUTHTOKENCOMMAND = _descriptor.Descriptor(
  name='GenerateAuthTokenCommand',
  full_name='com.elarian.hera.proto.GenerateAuthTokenCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3264,
  serialized_end=3290,
)


_GENERATEAUTHTOKENREPLY = _descriptor.Descriptor(
  name='GenerateAuthTokenReply',
  full_name='com.elarian.hera.proto.GenerateAuthTokenReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='com.elarian.hera.proto.GenerateAuthTokenReply.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lifetime', full_name='com.elarian.hera.proto.GenerateAuthTokenReply.lifetime', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3292,
  serialized_end=3376,
)


_GETCUSTOMERSTATECOMMAND = _descriptor.Descriptor(
  name='GetCustomerStateCommand',
  full_name='com.elarian.hera.proto.GetCustomerStateCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='com.elarian.hera.proto.GetCustomerStateCommand.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.GetCustomerStateCommand.customer_number', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secondary_id', full_name='com.elarian.hera.proto.GetCustomerStateCommand.secondary_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='customer', full_name='com.elarian.hera.proto.GetCustomerStateCommand.customer',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3379,
  serialized_end=3568,
)


_GETCUSTOMERSTATEREPLY = _descriptor.Descriptor(
  name='GetCustomerStateReply',
  full_name='com.elarian.hera.proto.GetCustomerStateReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='com.elarian.hera.proto.GetCustomerStateReply.status', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='com.elarian.hera.proto.GetCustomerStateReply.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='com.elarian.hera.proto.GetCustomerStateReply.data', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3570,
  serialized_end=3692,
)


_CUSTOMERSTATEREPLYDATA = _descriptor.Descriptor(
  name='CustomerStateReplyData',
  full_name='com.elarian.hera.proto.CustomerStateReplyData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='com.elarian.hera.proto.CustomerStateReplyData.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='identity_state', full_name='com.elarian.hera.proto.CustomerStateReplyData.identity_state', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='messaging_state', full_name='com.elarian.hera.proto.CustomerStateReplyData.messaging_state', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payment_state', full_name='com.elarian.hera.proto.CustomerStateReplyData.payment_state', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activity_state', full_name='com.elarian.hera.proto.CustomerStateReplyData.activity_state', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3695,
  serialized_end=3992,
)


_ADOPTCUSTOMERSTATECOMMAND = _descriptor.Descriptor(
  name='AdoptCustomerStateCommand',
  full_name='com.elarian.hera.proto.AdoptCustomerStateCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='com.elarian.hera.proto.AdoptCustomerStateCommand.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='other_customer_id', full_name='com.elarian.hera.proto.AdoptCustomerStateCommand.other_customer_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='other_customer_number', full_name='com.elarian.hera.proto.AdoptCustomerStateCommand.other_customer_number', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='other_secondary_id', full_name='com.elarian.hera.proto.AdoptCustomerStateCommand.other_secondary_id', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='other_customer', full_name='com.elarian.hera.proto.AdoptCustomerStateCommand.other_customer',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3995,
  serialized_end=4231,
)


_ADDCUSTOMERREMINDERCOMMAND = _descriptor.Descriptor(
  name='AddCustomerReminderCommand',
  full_name='com.elarian.hera.proto.AddCustomerReminderCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='com.elarian.hera.proto.AddCustomerReminderCommand.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.AddCustomerReminderCommand.customer_number', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secondary_id', full_name='com.elarian.hera.proto.AddCustomerReminderCommand.secondary_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reminder', full_name='com.elarian.hera.proto.AddCustomerReminderCommand.reminder', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='customer', full_name='com.elarian.hera.proto.AddCustomerReminderCommand.customer',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4234,
  serialized_end=4486,
)


_ADDCUSTOMERREMINDERTAGCOMMAND = _descriptor.Descriptor(
  name='AddCustomerReminderTagCommand',
  full_name='com.elarian.hera.proto.AddCustomerReminderTagCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag', full_name='com.elarian.hera.proto.AddCustomerReminderTagCommand.tag', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reminder', full_name='com.elarian.hera.proto.AddCustomerReminderTagCommand.reminder', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4489,
  serialized_end=4631,
)


_CANCELCUSTOMERREMINDERCOMMAND = _descriptor.Descriptor(
  name='CancelCustomerReminderCommand',
  full_name='com.elarian.hera.proto.CancelCustomerReminderCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='com.elarian.hera.proto.CancelCustomerReminderCommand.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.CancelCustomerReminderCommand.customer_number', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secondary_id', full_name='com.elarian.hera.proto.CancelCustomerReminderCommand.secondary_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='com.elarian.hera.proto.CancelCustomerReminderCommand.key', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='customer', full_name='com.elarian.hera.proto.CancelCustomerReminderCommand.customer',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4634,
  serialized_end=4842,
)


_CANCELCUSTOMERREMINDERTAGCOMMAND = _descriptor.Descriptor(
  name='CancelCustomerReminderTagCommand',
  full_name='com.elarian.hera.proto.CancelCustomerReminderTagCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag', full_name='com.elarian.hera.proto.CancelCustomerReminderTagCommand.tag', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='com.elarian.hera.proto.CancelCustomerReminderTagCommand.key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4844,
  serialized_end=4942,
)


_UPDATECUSTOMERTAGCOMMAND = _descriptor.Descriptor(
  name='UpdateCustomerTagCommand',
  full_name='com.elarian.hera.proto.UpdateCustomerTagCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='com.elarian.hera.proto.UpdateCustomerTagCommand.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.UpdateCustomerTagCommand.customer_number', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secondary_id', full_name='com.elarian.hera.proto.UpdateCustomerTagCommand.secondary_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updates', full_name='com.elarian.hera.proto.UpdateCustomerTagCommand.updates', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='customer', full_name='com.elarian.hera.proto.UpdateCustomerTagCommand.customer',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4945,
  serialized_end=5191,
)


_DELETECUSTOMERTAGCOMMAND = _descriptor.Descriptor(
  name='DeleteCustomerTagCommand',
  full_name='com.elarian.hera.proto.DeleteCustomerTagCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='com.elarian.hera.proto.DeleteCustomerTagCommand.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.DeleteCustomerTagCommand.customer_number', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secondary_id', full_name='com.elarian.hera.proto.DeleteCustomerTagCommand.secondary_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deletions', full_name='com.elarian.hera.proto.DeleteCustomerTagCommand.deletions', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='customer', full_name='com.elarian.hera.proto.DeleteCustomerTagCommand.customer',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=5194,
  serialized_end=5403,
)


_UPDATECUSTOMERSECONDARYIDCOMMAND = _descriptor.Descriptor(
  name='UpdateCustomerSecondaryIdCommand',
  full_name='com.elarian.hera.proto.UpdateCustomerSecondaryIdCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='com.elarian.hera.proto.UpdateCustomerSecondaryIdCommand.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.UpdateCustomerSecondaryIdCommand.customer_number', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secondary_id', full_name='com.elarian.hera.proto.UpdateCustomerSecondaryIdCommand.secondary_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updates', full_name='com.elarian.hera.proto.UpdateCustomerSecondaryIdCommand.updates', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='customer', full_name='com.elarian.hera.proto.UpdateCustomerSecondaryIdCommand.customer',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=5406,
  serialized_end=5660,
)


_DELETECUSTOMERSECONDARYIDCOMMAND = _descriptor.Descriptor(
  name='DeleteCustomerSecondaryIdCommand',
  full_name='com.elarian.hera.proto.DeleteCustomerSecondaryIdCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='com.elarian.hera.proto.DeleteCustomerSecondaryIdCommand.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.DeleteCustomerSecondaryIdCommand.customer_number', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secondary_id', full_name='com.elarian.hera.proto.DeleteCustomerSecondaryIdCommand.secondary_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deletions', full_name='com.elarian.hera.proto.DeleteCustomerSecondaryIdCommand.deletions', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='customer', full_name='com.elarian.hera.proto.DeleteCustomerSecondaryIdCommand.customer',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=5663,
  serialized_end=5918,
)


_UPDATECUSTOMERMETADATACOMMAND_UPDATESENTRY = _descriptor.Descriptor(
  name='UpdatesEntry',
  full_name='com.elarian.hera.proto.UpdateCustomerMetadataCommand.UpdatesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.elarian.hera.proto.UpdateCustomerMetadataCommand.UpdatesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.elarian.hera.proto.UpdateCustomerMetadataCommand.UpdatesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6191,
  serialized_end=6275,
)

_UPDATECUSTOMERMETADATACOMMAND = _descriptor.Descriptor(
  name='UpdateCustomerMetadataCommand',
  full_name='com.elarian.hera.proto.UpdateCustomerMetadataCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='com.elarian.hera.proto.UpdateCustomerMetadataCommand.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.UpdateCustomerMetadataCommand.customer_number', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secondary_id', full_name='com.elarian.hera.proto.UpdateCustomerMetadataCommand.secondary_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updates', full_name='com.elarian.hera.proto.UpdateCustomerMetadataCommand.updates', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATECUSTOMERMETADATACOMMAND_UPDATESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='customer', full_name='com.elarian.hera.proto.UpdateCustomerMetadataCommand.customer',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=5921,
  serialized_end=6287,
)


_DELETECUSTOMERMETADATACOMMAND = _descriptor.Descriptor(
  name='DeleteCustomerMetadataCommand',
  full_name='com.elarian.hera.proto.DeleteCustomerMetadataCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='com.elarian.hera.proto.DeleteCustomerMetadataCommand.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.DeleteCustomerMetadataCommand.customer_number', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secondary_id', full_name='com.elarian.hera.proto.DeleteCustomerMetadataCommand.secondary_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deletions', full_name='com.elarian.hera.proto.DeleteCustomerMetadataCommand.deletions', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='customer', full_name='com.elarian.hera.proto.DeleteCustomerMetadataCommand.customer',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=6290,
  serialized_end=6504,
)


_UPDATECUSTOMERSTATEREPLY = _descriptor.Descriptor(
  name='UpdateCustomerStateReply',
  full_name='com.elarian.hera.proto.UpdateCustomerStateReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='com.elarian.hera.proto.UpdateCustomerStateReply.status', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='com.elarian.hera.proto.UpdateCustomerStateReply.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='com.elarian.hera.proto.UpdateCustomerStateReply.customer_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6506,
  serialized_end=6620,
)


_UPDATECUSTOMERAPPDATACOMMAND = _descriptor.Descriptor(
  name='UpdateCustomerAppDataCommand',
  full_name='com.elarian.hera.proto.UpdateCustomerAppDataCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='com.elarian.hera.proto.UpdateCustomerAppDataCommand.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.UpdateCustomerAppDataCommand.customer_number', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secondary_id', full_name='com.elarian.hera.proto.UpdateCustomerAppDataCommand.secondary_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update', full_name='com.elarian.hera.proto.UpdateCustomerAppDataCommand.update', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='customer', full_name='com.elarian.hera.proto.UpdateCustomerAppDataCommand.customer',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=6623,
  serialized_end=6871,
)


_DELETECUSTOMERAPPDATACOMMAND = _descriptor.Descriptor(
  name='DeleteCustomerAppDataCommand',
  full_name='com.elarian.hera.proto.DeleteCustomerAppDataCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='com.elarian.hera.proto.DeleteCustomerAppDataCommand.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.DeleteCustomerAppDataCommand.customer_number', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secondary_id', full_name='com.elarian.hera.proto.DeleteCustomerAppDataCommand.secondary_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='customer', full_name='com.elarian.hera.proto.DeleteCustomerAppDataCommand.customer',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=6874,
  serialized_end=7068,
)


_UPDATECUSTOMERAPPDATAREPLY = _descriptor.Descriptor(
  name='UpdateCustomerAppDataReply',
  full_name='com.elarian.hera.proto.UpdateCustomerAppDataReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='com.elarian.hera.proto.UpdateCustomerAppDataReply.status', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='com.elarian.hera.proto.UpdateCustomerAppDataReply.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='com.elarian.hera.proto.UpdateCustomerAppDataReply.customer_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7070,
  serialized_end=7186,
)


_LEASECUSTOMERAPPDATACOMMAND = _descriptor.Descriptor(
  name='LeaseCustomerAppDataCommand',
  full_name='com.elarian.hera.proto.LeaseCustomerAppDataCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='com.elarian.hera.proto.LeaseCustomerAppDataCommand.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.LeaseCustomerAppDataCommand.customer_number', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secondary_id', full_name='com.elarian.hera.proto.LeaseCustomerAppDataCommand.secondary_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='customer', full_name='com.elarian.hera.proto.LeaseCustomerAppDataCommand.customer',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=7189,
  serialized_end=7382,
)


_LEASECUSTOMERAPPDATAREPLY = _descriptor.Descriptor(
  name='LeaseCustomerAppDataReply',
  full_name='com.elarian.hera.proto.LeaseCustomerAppDataReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='com.elarian.hera.proto.LeaseCustomerAppDataReply.status', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='com.elarian.hera.proto.LeaseCustomerAppDataReply.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='com.elarian.hera.proto.LeaseCustomerAppDataReply.customer_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.elarian.hera.proto.LeaseCustomerAppDataReply.value', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7385,
  serialized_end=7553,
)


_SENDMESSAGECOMMAND = _descriptor.Descriptor(
  name='SendMessageCommand',
  full_name='com.elarian.hera.proto.SendMessageCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.SendMessageCommand.customer_number', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='com.elarian.hera.proto.SendMessageCommand.channel_number', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='com.elarian.hera.proto.SendMessageCommand.message', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7556,
  serialized_end=7771,
)


_REPLYTOMESSAGECOMMAND = _descriptor.Descriptor(
  name='ReplyToMessageCommand',
  full_name='com.elarian.hera.proto.ReplyToMessageCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='com.elarian.hera.proto.ReplyToMessageCommand.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_id', full_name='com.elarian.hera.proto.ReplyToMessageCommand.message_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='com.elarian.hera.proto.ReplyToMessageCommand.message', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7773,
  serialized_end=7895,
)


_SENDMESSAGETAGCOMMAND = _descriptor.Descriptor(
  name='SendMessageTagCommand',
  full_name='com.elarian.hera.proto.SendMessageTagCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag', full_name='com.elarian.hera.proto.SendMessageTagCommand.tag', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='com.elarian.hera.proto.SendMessageTagCommand.channel_number', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='com.elarian.hera.proto.SendMessageTagCommand.message', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7898,
  serialized_end=8102,
)


_SENDMESSAGEREPLY = _descriptor.Descriptor(
  name='SendMessageReply',
  full_name='com.elarian.hera.proto.SendMessageReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='com.elarian.hera.proto.SendMessageReply.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='com.elarian.hera.proto.SendMessageReply.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_id', full_name='com.elarian.hera.proto.SendMessageReply.message_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='com.elarian.hera.proto.SendMessageReply.session_id', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='com.elarian.hera.proto.SendMessageReply.customer_id', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8105,
  serialized_end=8358,
)


_UPDATEMESSAGINGCONSENTCOMMAND = _descriptor.Descriptor(
  name='UpdateMessagingConsentCommand',
  full_name='com.elarian.hera.proto.UpdateMessagingConsentCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.UpdateMessagingConsentCommand.customer_number', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='com.elarian.hera.proto.UpdateMessagingConsentCommand.channel_number', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update', full_name='com.elarian.hera.proto.UpdateMessagingConsentCommand.update', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8361,
  serialized_end=8593,
)


_UPDATEMESSAGINGCONSENTREPLY = _descriptor.Descriptor(
  name='UpdateMessagingConsentReply',
  full_name='com.elarian.hera.proto.UpdateMessagingConsentReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='com.elarian.hera.proto.UpdateMessagingConsentReply.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='com.elarian.hera.proto.UpdateMessagingConsentReply.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='com.elarian.hera.proto.UpdateMessagingConsentReply.customer_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8596,
  serialized_end=8767,
)


_INITIATEPAYMENTCOMMAND = _descriptor.Descriptor(
  name='InitiatePaymentCommand',
  full_name='com.elarian.hera.proto.InitiatePaymentCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='debit_party', full_name='com.elarian.hera.proto.InitiatePaymentCommand.debit_party', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='credit_party', full_name='com.elarian.hera.proto.InitiatePaymentCommand.credit_party', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.elarian.hera.proto.InitiatePaymentCommand.value', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8770,
  serialized_end=8972,
)


_INITIATEPAYMENTREPLY = _descriptor.Descriptor(
  name='InitiatePaymentReply',
  full_name='com.elarian.hera.proto.InitiatePaymentReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='com.elarian.hera.proto.InitiatePaymentReply.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='com.elarian.hera.proto.InitiatePaymentReply.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transaction_id', full_name='com.elarian.hera.proto.InitiatePaymentReply.transaction_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='debit_customer_id', full_name='com.elarian.hera.proto.InitiatePaymentReply.debit_customer_id', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='credit_customer_id', full_name='com.elarian.hera.proto.InitiatePaymentReply.credit_customer_id', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8975,
  serialized_end=9242,
)


_TAGCOMMANDREPLY = _descriptor.Descriptor(
  name='TagCommandReply',
  full_name='com.elarian.hera.proto.TagCommandReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='com.elarian.hera.proto.TagCommandReply.status', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='com.elarian.hera.proto.TagCommandReply.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='work_id', full_name='com.elarian.hera.proto.TagCommandReply.work_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9244,
  serialized_end=9345,
)


_CUSTOMERACTIVITYCOMMAND_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='com.elarian.hera.proto.CustomerActivityCommand.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.elarian.hera.proto.CustomerActivityCommand.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.elarian.hera.proto.CustomerActivityCommand.PropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9629,
  serialized_end=9678,
)

_CUSTOMERACTIVITYCOMMAND = _descriptor.Descriptor(
  name='CustomerActivityCommand',
  full_name='com.elarian.hera.proto.CustomerActivityCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.CustomerActivityCommand.customer_number', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='com.elarian.hera.proto.CustomerActivityCommand.channel_number', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='com.elarian.hera.proto.CustomerActivityCommand.session_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='com.elarian.hera.proto.CustomerActivityCommand.key', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='properties', full_name='com.elarian.hera.proto.CustomerActivityCommand.properties', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CUSTOMERACTIVITYCOMMAND_PROPERTIESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9348,
  serialized_end=9678,
)


_CUSTOMERACTIVITYREPLY = _descriptor.Descriptor(
  name='CustomerActivityReply',
  full_name='com.elarian.hera.proto.CustomerActivityReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='com.elarian.hera.proto.CustomerActivityReply.status', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='com.elarian.hera.proto.CustomerActivityReply.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='com.elarian.hera.proto.CustomerActivityReply.customer_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9680,
  serialized_end=9791,
)


_SERVERTOAPPNOTIFICATION = _descriptor.Descriptor(
  name='ServerToAppNotification',
  full_name='com.elarian.hera.proto.ServerToAppNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer', full_name='com.elarian.hera.proto.ServerToAppNotification.customer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='purse', full_name='com.elarian.hera.proto.ServerToAppNotification.purse', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='entry', full_name='com.elarian.hera.proto.ServerToAppNotification.entry',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=9794,
  serialized_end=9976,
)


_SERVERTOAPPCUSTOMERNOTIFICATION = _descriptor.Descriptor(
  name='ServerToAppCustomerNotification',
  full_name='com.elarian.hera.proto.ServerToAppCustomerNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='org_id', full_name='com.elarian.hera.proto.ServerToAppCustomerNotification.org_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='com.elarian.hera.proto.ServerToAppCustomerNotification.app_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='com.elarian.hera.proto.ServerToAppCustomerNotification.customer_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_data', full_name='com.elarian.hera.proto.ServerToAppCustomerNotification.app_data', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='com.elarian.hera.proto.ServerToAppCustomerNotification.created_at', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reminder', full_name='com.elarian.hera.proto.ServerToAppCustomerNotification.reminder', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='messaging_session_started', full_name='com.elarian.hera.proto.ServerToAppCustomerNotification.messaging_session_started', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='messaging_session_renewed', full_name='com.elarian.hera.proto.ServerToAppCustomerNotification.messaging_session_renewed', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='messaging_session_ended', full_name='com.elarian.hera.proto.ServerToAppCustomerNotification.messaging_session_ended', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='messaging_consent_update', full_name='com.elarian.hera.proto.ServerToAppCustomerNotification.messaging_consent_update', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='received_message', full_name='com.elarian.hera.proto.ServerToAppCustomerNotification.received_message', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_status', full_name='com.elarian.hera.proto.ServerToAppCustomerNotification.message_status', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sent_message_reaction', full_name='com.elarian.hera.proto.ServerToAppCustomerNotification.sent_message_reaction', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='received_payment', full_name='com.elarian.hera.proto.ServerToAppCustomerNotification.received_payment', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payment_status', full_name='com.elarian.hera.proto.ServerToAppCustomerNotification.payment_status', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wallet_payment_status', full_name='com.elarian.hera.proto.ServerToAppCustomerNotification.wallet_payment_status', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_activity', full_name='com.elarian.hera.proto.ServerToAppCustomerNotification.customer_activity', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='entry', full_name='com.elarian.hera.proto.ServerToAppCustomerNotification.entry',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=9979,
  serialized_end=11209,
)


_SERVERTOAPPPURSENOTIFICATION = _descriptor.Descriptor(
  name='ServerToAppPurseNotification',
  full_name='com.elarian.hera.proto.ServerToAppPurseNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='org_id', full_name='com.elarian.hera.proto.ServerToAppPurseNotification.org_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='com.elarian.hera.proto.ServerToAppPurseNotification.app_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='purse_id', full_name='com.elarian.hera.proto.ServerToAppPurseNotification.purse_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='com.elarian.hera.proto.ServerToAppPurseNotification.created_at', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payment_status', full_name='com.elarian.hera.proto.ServerToAppPurseNotification.payment_status', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='entry', full_name='com.elarian.hera.proto.ServerToAppPurseNotification.entry',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=11212,
  serialized_end=11426,
)


_APPDATAUPDATE = _descriptor.Descriptor(
  name='AppDataUpdate',
  full_name='com.elarian.hera.proto.AppDataUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='com.elarian.hera.proto.AppDataUpdate.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11428,
  serialized_end=11495,
)


_SERVERTOAPPNOTIFICATIONREPLY = _descriptor.Descriptor(
  name='ServerToAppNotificationReply',
  full_name='com.elarian.hera.proto.ServerToAppNotificationReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_update', full_name='com.elarian.hera.proto.ServerToAppNotificationReply.data_update', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='com.elarian.hera.proto.ServerToAppNotificationReply.message', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11498,
  serialized_end=11646,
)


_REMINDERNOTIFICATION = _descriptor.Descriptor(
  name='ReminderNotification',
  full_name='com.elarian.hera.proto.ReminderNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reminder', full_name='com.elarian.hera.proto.ReminderNotification.reminder', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tag', full_name='com.elarian.hera.proto.ReminderNotification.tag', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='work_id', full_name='com.elarian.hera.proto.ReminderNotification.work_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11649,
  serialized_end=11830,
)


_MESSAGINGSESSIONSTARTEDNOTIFICATION = _descriptor.Descriptor(
  name='MessagingSessionStartedNotification',
  full_name='com.elarian.hera.proto.MessagingSessionStartedNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.MessagingSessionStartedNotification.customer_number', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='com.elarian.hera.proto.MessagingSessionStartedNotification.channel_number', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='com.elarian.hera.proto.MessagingSessionStartedNotification.session_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expires_at', full_name='com.elarian.hera.proto.MessagingSessionStartedNotification.expires_at', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11833,
  serialized_end=12075,
)


_MESSAGINGSESSIONRENEWEDNOTIFICATION = _descriptor.Descriptor(
  name='MessagingSessionRenewedNotification',
  full_name='com.elarian.hera.proto.MessagingSessionRenewedNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.MessagingSessionRenewedNotification.customer_number', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='com.elarian.hera.proto.MessagingSessionRenewedNotification.channel_number', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='com.elarian.hera.proto.MessagingSessionRenewedNotification.session_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expires_at', full_name='com.elarian.hera.proto.MessagingSessionRenewedNotification.expires_at', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12078,
  serialized_end=12320,
)


_MESSAGINGSESSIONENDEDNOTIFICATION = _descriptor.Descriptor(
  name='MessagingSessionEndedNotification',
  full_name='com.elarian.hera.proto.MessagingSessionEndedNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.MessagingSessionEndedNotification.customer_number', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='com.elarian.hera.proto.MessagingSessionEndedNotification.channel_number', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='com.elarian.hera.proto.MessagingSessionEndedNotification.session_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='duration', full_name='com.elarian.hera.proto.MessagingSessionEndedNotification.duration', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='com.elarian.hera.proto.MessagingSessionEndedNotification.reason', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12323,
  serialized_end=12627,
)


_MESSAGINGCONSENTUPDATENOTIFICATION = _descriptor.Descriptor(
  name='MessagingConsentUpdateNotification',
  full_name='com.elarian.hera.proto.MessagingConsentUpdateNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.MessagingConsentUpdateNotification.customer_number', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='com.elarian.hera.proto.MessagingConsentUpdateNotification.channel_number', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update', full_name='com.elarian.hera.proto.MessagingConsentUpdateNotification.update', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='com.elarian.hera.proto.MessagingConsentUpdateNotification.status', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12630,
  serialized_end=12937,
)


_RECEIVEDMESSAGENOTIFICATION = _descriptor.Descriptor(
  name='ReceivedMessageNotification',
  full_name='com.elarian.hera.proto.ReceivedMessageNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message_id', full_name='com.elarian.hera.proto.ReceivedMessageNotification.message_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.ReceivedMessageNotification.customer_number', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='com.elarian.hera.proto.ReceivedMessageNotification.channel_number', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parts', full_name='com.elarian.hera.proto.ReceivedMessageNotification.parts', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='com.elarian.hera.proto.ReceivedMessageNotification.session_id', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='in_reply_to', full_name='com.elarian.hera.proto.ReceivedMessageNotification.in_reply_to', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12940,
  serialized_end=13286,
)


_MESSAGESTATUSNOTIFICATION = _descriptor.Descriptor(
  name='MessageStatusNotification',
  full_name='com.elarian.hera.proto.MessageStatusNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message_id', full_name='com.elarian.hera.proto.MessageStatusNotification.message_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='com.elarian.hera.proto.MessageStatusNotification.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13288,
  serialized_end=13398,
)


_SENTMESSAGEREACTIONNOTIFICATION = _descriptor.Descriptor(
  name='SentMessageReactionNotification',
  full_name='com.elarian.hera.proto.SentMessageReactionNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message_id', full_name='com.elarian.hera.proto.SentMessageReactionNotification.message_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.SentMessageReactionNotification.customer_number', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='com.elarian.hera.proto.SentMessageReactionNotification.channel_number', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reaction', full_name='com.elarian.hera.proto.SentMessageReactionNotification.reaction', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13401,
  serialized_end=13650,
)


_RECEIVEDPAYMENTNOTIFICATION = _descriptor.Descriptor(
  name='ReceivedPaymentNotification',
  full_name='com.elarian.hera.proto.ReceivedPaymentNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='purse_id', full_name='com.elarian.hera.proto.ReceivedPaymentNotification.purse_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transaction_id', full_name='com.elarian.hera.proto.ReceivedPaymentNotification.transaction_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.ReceivedPaymentNotification.customer_number', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='com.elarian.hera.proto.ReceivedPaymentNotification.channel_number', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.elarian.hera.proto.ReceivedPaymentNotification.value', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='com.elarian.hera.proto.ReceivedPaymentNotification.status', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13653,
  serialized_end=13959,
)


_PAYMENTSTATUSNOTIFICATION = _descriptor.Descriptor(
  name='PaymentStatusNotification',
  full_name='com.elarian.hera.proto.PaymentStatusNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transaction_id', full_name='com.elarian.hera.proto.PaymentStatusNotification.transaction_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='com.elarian.hera.proto.PaymentStatusNotification.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13961,
  serialized_end=14067,
)


_WALLETPAYMENTSTATUSNOTIFICATION = _descriptor.Descriptor(
  name='WalletPaymentStatusNotification',
  full_name='com.elarian.hera.proto.WalletPaymentStatusNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wallet_id', full_name='com.elarian.hera.proto.WalletPaymentStatusNotification.wallet_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transaction_id', full_name='com.elarian.hera.proto.WalletPaymentStatusNotification.transaction_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='com.elarian.hera.proto.WalletPaymentStatusNotification.status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14070,
  serialized_end=14201,
)


_CUSTOMERACTIVITYNOTIFICATION = _descriptor.Descriptor(
  name='CustomerActivityNotification',
  full_name='com.elarian.hera.proto.CustomerActivityNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.CustomerActivityNotification.customer_number', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='com.elarian.hera.proto.CustomerActivityNotification.channel_number', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='com.elarian.hera.proto.CustomerActivityNotification.session_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activity', full_name='com.elarian.hera.proto.CustomerActivityNotification.activity', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14204,
  serialized_end=14450,
)

_APPCONNECTIONMETADATA.fields_by_name['api_key'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_APPCONNECTIONMETADATA.fields_by_name['auth_token'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_APPTOSERVERCOMMAND.fields_by_name['generate_auth_token'].message_type = _GENERATEAUTHTOKENCOMMAND
_APPTOSERVERCOMMAND.fields_by_name['get_customer_state'].message_type = _GETCUSTOMERSTATECOMMAND
_APPTOSERVERCOMMAND.fields_by_name['adopt_customer_state'].message_type = _ADOPTCUSTOMERSTATECOMMAND
_APPTOSERVERCOMMAND.fields_by_name['add_customer_reminder'].message_type = _ADDCUSTOMERREMINDERCOMMAND
_APPTOSERVERCOMMAND.fields_by_name['add_customer_reminder_tag'].message_type = _ADDCUSTOMERREMINDERTAGCOMMAND
_APPTOSERVERCOMMAND.fields_by_name['cancel_customer_reminder'].message_type = _CANCELCUSTOMERREMINDERCOMMAND
_APPTOSERVERCOMMAND.fields_by_name['cancel_customer_reminder_tag'].message_type = _CANCELCUSTOMERREMINDERTAGCOMMAND
_APPTOSERVERCOMMAND.fields_by_name['update_customer_tag'].message_type = _UPDATECUSTOMERTAGCOMMAND
_APPTOSERVERCOMMAND.fields_by_name['delete_customer_tag'].message_type = _DELETECUSTOMERTAGCOMMAND
_APPTOSERVERCOMMAND.fields_by_name['update_customer_secondary_id'].message_type = _UPDATECUSTOMERSECONDARYIDCOMMAND
_APPTOSERVERCOMMAND.fields_by_name['delete_customer_secondary_id'].message_type = _DELETECUSTOMERSECONDARYIDCOMMAND
_APPTOSERVERCOMMAND.fields_by_name['update_customer_metadata'].message_type = _UPDATECUSTOMERMETADATACOMMAND
_APPTOSERVERCOMMAND.fields_by_name['delete_customer_metadata'].message_type = _DELETECUSTOMERMETADATACOMMAND
_APPTOSERVERCOMMAND.fields_by_name['lease_customer_app_data'].message_type = _LEASECUSTOMERAPPDATACOMMAND
_APPTOSERVERCOMMAND.fields_by_name['update_customer_app_data'].message_type = _UPDATECUSTOMERAPPDATACOMMAND
_APPTOSERVERCOMMAND.fields_by_name['delete_customer_app_data'].message_type = _DELETECUSTOMERAPPDATACOMMAND
_APPTOSERVERCOMMAND.fields_by_name['send_message'].message_type = _SENDMESSAGECOMMAND
_APPTOSERVERCOMMAND.fields_by_name['send_message_tag'].message_type = _SENDMESSAGETAGCOMMAND
_APPTOSERVERCOMMAND.fields_by_name['reply_to_message'].message_type = _REPLYTOMESSAGECOMMAND
_APPTOSERVERCOMMAND.fields_by_name['update_messaging_consent'].message_type = _UPDATEMESSAGINGCONSENTCOMMAND
_APPTOSERVERCOMMAND.fields_by_name['initiate_payment'].message_type = _INITIATEPAYMENTCOMMAND
_APPTOSERVERCOMMAND.fields_by_name['customer_activity'].message_type = _CUSTOMERACTIVITYCOMMAND
_APPTOSERVERCOMMAND.oneofs_by_name['entry'].fields.append(
  _APPTOSERVERCOMMAND.fields_by_name['generate_auth_token'])
_APPTOSERVERCOMMAND.fields_by_name['generate_auth_token'].containing_oneof = _APPTOSERVERCOMMAND.oneofs_by_name['entry']
_APPTOSERVERCOMMAND.oneofs_by_name['entry'].fields.append(
  _APPTOSERVERCOMMAND.fields_by_name['get_customer_state'])
_APPTOSERVERCOMMAND.fields_by_name['get_customer_state'].containing_oneof = _APPTOSERVERCOMMAND.oneofs_by_name['entry']
_APPTOSERVERCOMMAND.oneofs_by_name['entry'].fields.append(
  _APPTOSERVERCOMMAND.fields_by_name['adopt_customer_state'])
_APPTOSERVERCOMMAND.fields_by_name['adopt_customer_state'].containing_oneof = _APPTOSERVERCOMMAND.oneofs_by_name['entry']
_APPTOSERVERCOMMAND.oneofs_by_name['entry'].fields.append(
  _APPTOSERVERCOMMAND.fields_by_name['add_customer_reminder'])
_APPTOSERVERCOMMAND.fields_by_name['add_customer_reminder'].containing_oneof = _APPTOSERVERCOMMAND.oneofs_by_name['entry']
_APPTOSERVERCOMMAND.oneofs_by_name['entry'].fields.append(
  _APPTOSERVERCOMMAND.fields_by_name['add_customer_reminder_tag'])
_APPTOSERVERCOMMAND.fields_by_name['add_customer_reminder_tag'].containing_oneof = _APPTOSERVERCOMMAND.oneofs_by_name['entry']
_APPTOSERVERCOMMAND.oneofs_by_name['entry'].fields.append(
  _APPTOSERVERCOMMAND.fields_by_name['cancel_customer_reminder'])
_APPTOSERVERCOMMAND.fields_by_name['cancel_customer_reminder'].containing_oneof = _APPTOSERVERCOMMAND.oneofs_by_name['entry']
_APPTOSERVERCOMMAND.oneofs_by_name['entry'].fields.append(
  _APPTOSERVERCOMMAND.fields_by_name['cancel_customer_reminder_tag'])
_APPTOSERVERCOMMAND.fields_by_name['cancel_customer_reminder_tag'].containing_oneof = _APPTOSERVERCOMMAND.oneofs_by_name['entry']
_APPTOSERVERCOMMAND.oneofs_by_name['entry'].fields.append(
  _APPTOSERVERCOMMAND.fields_by_name['update_customer_tag'])
_APPTOSERVERCOMMAND.fields_by_name['update_customer_tag'].containing_oneof = _APPTOSERVERCOMMAND.oneofs_by_name['entry']
_APPTOSERVERCOMMAND.oneofs_by_name['entry'].fields.append(
  _APPTOSERVERCOMMAND.fields_by_name['delete_customer_tag'])
_APPTOSERVERCOMMAND.fields_by_name['delete_customer_tag'].containing_oneof = _APPTOSERVERCOMMAND.oneofs_by_name['entry']
_APPTOSERVERCOMMAND.oneofs_by_name['entry'].fields.append(
  _APPTOSERVERCOMMAND.fields_by_name['update_customer_secondary_id'])
_APPTOSERVERCOMMAND.fields_by_name['update_customer_secondary_id'].containing_oneof = _APPTOSERVERCOMMAND.oneofs_by_name['entry']
_APPTOSERVERCOMMAND.oneofs_by_name['entry'].fields.append(
  _APPTOSERVERCOMMAND.fields_by_name['delete_customer_secondary_id'])
_APPTOSERVERCOMMAND.fields_by_name['delete_customer_secondary_id'].containing_oneof = _APPTOSERVERCOMMAND.oneofs_by_name['entry']
_APPTOSERVERCOMMAND.oneofs_by_name['entry'].fields.append(
  _APPTOSERVERCOMMAND.fields_by_name['update_customer_metadata'])
_APPTOSERVERCOMMAND.fields_by_name['update_customer_metadata'].containing_oneof = _APPTOSERVERCOMMAND.oneofs_by_name['entry']
_APPTOSERVERCOMMAND.oneofs_by_name['entry'].fields.append(
  _APPTOSERVERCOMMAND.fields_by_name['delete_customer_metadata'])
_APPTOSERVERCOMMAND.fields_by_name['delete_customer_metadata'].containing_oneof = _APPTOSERVERCOMMAND.oneofs_by_name['entry']
_APPTOSERVERCOMMAND.oneofs_by_name['entry'].fields.append(
  _APPTOSERVERCOMMAND.fields_by_name['lease_customer_app_data'])
_APPTOSERVERCOMMAND.fields_by_name['lease_customer_app_data'].containing_oneof = _APPTOSERVERCOMMAND.oneofs_by_name['entry']
_APPTOSERVERCOMMAND.oneofs_by_name['entry'].fields.append(
  _APPTOSERVERCOMMAND.fields_by_name['update_customer_app_data'])
_APPTOSERVERCOMMAND.fields_by_name['update_customer_app_data'].containing_oneof = _APPTOSERVERCOMMAND.oneofs_by_name['entry']
_APPTOSERVERCOMMAND.oneofs_by_name['entry'].fields.append(
  _APPTOSERVERCOMMAND.fields_by_name['delete_customer_app_data'])
_APPTOSERVERCOMMAND.fields_by_name['delete_customer_app_data'].containing_oneof = _APPTOSERVERCOMMAND.oneofs_by_name['entry']
_APPTOSERVERCOMMAND.oneofs_by_name['entry'].fields.append(
  _APPTOSERVERCOMMAND.fields_by_name['send_message'])
_APPTOSERVERCOMMAND.fields_by_name['send_message'].containing_oneof = _APPTOSERVERCOMMAND.oneofs_by_name['entry']
_APPTOSERVERCOMMAND.oneofs_by_name['entry'].fields.append(
  _APPTOSERVERCOMMAND.fields_by_name['send_message_tag'])
_APPTOSERVERCOMMAND.fields_by_name['send_message_tag'].containing_oneof = _APPTOSERVERCOMMAND.oneofs_by_name['entry']
_APPTOSERVERCOMMAND.oneofs_by_name['entry'].fields.append(
  _APPTOSERVERCOMMAND.fields_by_name['reply_to_message'])
_APPTOSERVERCOMMAND.fields_by_name['reply_to_message'].containing_oneof = _APPTOSERVERCOMMAND.oneofs_by_name['entry']
_APPTOSERVERCOMMAND.oneofs_by_name['entry'].fields.append(
  _APPTOSERVERCOMMAND.fields_by_name['update_messaging_consent'])
_APPTOSERVERCOMMAND.fields_by_name['update_messaging_consent'].containing_oneof = _APPTOSERVERCOMMAND.oneofs_by_name['entry']
_APPTOSERVERCOMMAND.oneofs_by_name['entry'].fields.append(
  _APPTOSERVERCOMMAND.fields_by_name['initiate_payment'])
_APPTOSERVERCOMMAND.fields_by_name['initiate_payment'].containing_oneof = _APPTOSERVERCOMMAND.oneofs_by_name['entry']
_APPTOSERVERCOMMAND.oneofs_by_name['entry'].fields.append(
  _APPTOSERVERCOMMAND.fields_by_name['customer_activity'])
_APPTOSERVERCOMMAND.fields_by_name['customer_activity'].containing_oneof = _APPTOSERVERCOMMAND.oneofs_by_name['entry']
_APPTOSERVERCOMMANDREPLY.fields_by_name['generate_auth_token'].message_type = _GENERATEAUTHTOKENREPLY
_APPTOSERVERCOMMANDREPLY.fields_by_name['get_customer_state'].message_type = _GETCUSTOMERSTATEREPLY
_APPTOSERVERCOMMANDREPLY.fields_by_name['update_customer_state'].message_type = _UPDATECUSTOMERSTATEREPLY
_APPTOSERVERCOMMANDREPLY.fields_by_name['update_customer_app_data'].message_type = _UPDATECUSTOMERAPPDATAREPLY
_APPTOSERVERCOMMANDREPLY.fields_by_name['lease_customer_app_data'].message_type = _LEASECUSTOMERAPPDATAREPLY
_APPTOSERVERCOMMANDREPLY.fields_by_name['send_message'].message_type = _SENDMESSAGEREPLY
_APPTOSERVERCOMMANDREPLY.fields_by_name['update_messaging_consent'].message_type = _UPDATEMESSAGINGCONSENTREPLY
_APPTOSERVERCOMMANDREPLY.fields_by_name['initiate_payment'].message_type = _INITIATEPAYMENTREPLY
_APPTOSERVERCOMMANDREPLY.fields_by_name['tag_command'].message_type = _TAGCOMMANDREPLY
_APPTOSERVERCOMMANDREPLY.fields_by_name['customer_activity'].message_type = _CUSTOMERACTIVITYREPLY
_APPTOSERVERCOMMANDREPLY.oneofs_by_name['entry'].fields.append(
  _APPTOSERVERCOMMANDREPLY.fields_by_name['generate_auth_token'])
_APPTOSERVERCOMMANDREPLY.fields_by_name['generate_auth_token'].containing_oneof = _APPTOSERVERCOMMANDREPLY.oneofs_by_name['entry']
_APPTOSERVERCOMMANDREPLY.oneofs_by_name['entry'].fields.append(
  _APPTOSERVERCOMMANDREPLY.fields_by_name['get_customer_state'])
_APPTOSERVERCOMMANDREPLY.fields_by_name['get_customer_state'].containing_oneof = _APPTOSERVERCOMMANDREPLY.oneofs_by_name['entry']
_APPTOSERVERCOMMANDREPLY.oneofs_by_name['entry'].fields.append(
  _APPTOSERVERCOMMANDREPLY.fields_by_name['update_customer_state'])
_APPTOSERVERCOMMANDREPLY.fields_by_name['update_customer_state'].containing_oneof = _APPTOSERVERCOMMANDREPLY.oneofs_by_name['entry']
_APPTOSERVERCOMMANDREPLY.oneofs_by_name['entry'].fields.append(
  _APPTOSERVERCOMMANDREPLY.fields_by_name['update_customer_app_data'])
_APPTOSERVERCOMMANDREPLY.fields_by_name['update_customer_app_data'].containing_oneof = _APPTOSERVERCOMMANDREPLY.oneofs_by_name['entry']
_APPTOSERVERCOMMANDREPLY.oneofs_by_name['entry'].fields.append(
  _APPTOSERVERCOMMANDREPLY.fields_by_name['lease_customer_app_data'])
_APPTOSERVERCOMMANDREPLY.fields_by_name['lease_customer_app_data'].containing_oneof = _APPTOSERVERCOMMANDREPLY.oneofs_by_name['entry']
_APPTOSERVERCOMMANDREPLY.oneofs_by_name['entry'].fields.append(
  _APPTOSERVERCOMMANDREPLY.fields_by_name['send_message'])
_APPTOSERVERCOMMANDREPLY.fields_by_name['send_message'].containing_oneof = _APPTOSERVERCOMMANDREPLY.oneofs_by_name['entry']
_APPTOSERVERCOMMANDREPLY.oneofs_by_name['entry'].fields.append(
  _APPTOSERVERCOMMANDREPLY.fields_by_name['update_messaging_consent'])
_APPTOSERVERCOMMANDREPLY.fields_by_name['update_messaging_consent'].containing_oneof = _APPTOSERVERCOMMANDREPLY.oneofs_by_name['entry']
_APPTOSERVERCOMMANDREPLY.oneofs_by_name['entry'].fields.append(
  _APPTOSERVERCOMMANDREPLY.fields_by_name['initiate_payment'])
_APPTOSERVERCOMMANDREPLY.fields_by_name['initiate_payment'].containing_oneof = _APPTOSERVERCOMMANDREPLY.oneofs_by_name['entry']
_APPTOSERVERCOMMANDREPLY.oneofs_by_name['entry'].fields.append(
  _APPTOSERVERCOMMANDREPLY.fields_by_name['tag_command'])
_APPTOSERVERCOMMANDREPLY.fields_by_name['tag_command'].containing_oneof = _APPTOSERVERCOMMANDREPLY.oneofs_by_name['entry']
_APPTOSERVERCOMMANDREPLY.oneofs_by_name['entry'].fields.append(
  _APPTOSERVERCOMMANDREPLY.fields_by_name['customer_activity'])
_APPTOSERVERCOMMANDREPLY.fields_by_name['customer_activity'].containing_oneof = _APPTOSERVERCOMMANDREPLY.oneofs_by_name['entry']
_GENERATEAUTHTOKENREPLY.fields_by_name['lifetime'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_GETCUSTOMERSTATECOMMAND.fields_by_name['customer_number'].message_type = common__model__pb2._CUSTOMERNUMBER
_GETCUSTOMERSTATECOMMAND.fields_by_name['secondary_id'].message_type = common__model__pb2._INDEXMAPPING
_GETCUSTOMERSTATECOMMAND.oneofs_by_name['customer'].fields.append(
  _GETCUSTOMERSTATECOMMAND.fields_by_name['customer_id'])
_GETCUSTOMERSTATECOMMAND.fields_by_name['customer_id'].containing_oneof = _GETCUSTOMERSTATECOMMAND.oneofs_by_name['customer']
_GETCUSTOMERSTATECOMMAND.oneofs_by_name['customer'].fields.append(
  _GETCUSTOMERSTATECOMMAND.fields_by_name['customer_number'])
_GETCUSTOMERSTATECOMMAND.fields_by_name['customer_number'].containing_oneof = _GETCUSTOMERSTATECOMMAND.oneofs_by_name['customer']
_GETCUSTOMERSTATECOMMAND.oneofs_by_name['customer'].fields.append(
  _GETCUSTOMERSTATECOMMAND.fields_by_name['secondary_id'])
_GETCUSTOMERSTATECOMMAND.fields_by_name['secondary_id'].containing_oneof = _GETCUSTOMERSTATECOMMAND.oneofs_by_name['customer']
_GETCUSTOMERSTATEREPLY.fields_by_name['data'].message_type = _CUSTOMERSTATEREPLYDATA
_CUSTOMERSTATEREPLYDATA.fields_by_name['identity_state'].message_type = identity__state__pb2._IDENTITYSTATE
_CUSTOMERSTATEREPLYDATA.fields_by_name['messaging_state'].message_type = messaging__state__pb2._MESSAGINGSTATE
_CUSTOMERSTATEREPLYDATA.fields_by_name['payment_state'].message_type = payment__state__pb2._PAYMENTSTATE
_CUSTOMERSTATEREPLYDATA.fields_by_name['activity_state'].message_type = activity__state__pb2._ACTIVITYSTATE
_ADOPTCUSTOMERSTATECOMMAND.fields_by_name['other_customer_number'].message_type = common__model__pb2._CUSTOMERNUMBER
_ADOPTCUSTOMERSTATECOMMAND.fields_by_name['other_secondary_id'].message_type = common__model__pb2._INDEXMAPPING
_ADOPTCUSTOMERSTATECOMMAND.oneofs_by_name['other_customer'].fields.append(
  _ADOPTCUSTOMERSTATECOMMAND.fields_by_name['other_customer_id'])
_ADOPTCUSTOMERSTATECOMMAND.fields_by_name['other_customer_id'].containing_oneof = _ADOPTCUSTOMERSTATECOMMAND.oneofs_by_name['other_customer']
_ADOPTCUSTOMERSTATECOMMAND.oneofs_by_name['other_customer'].fields.append(
  _ADOPTCUSTOMERSTATECOMMAND.fields_by_name['other_customer_number'])
_ADOPTCUSTOMERSTATECOMMAND.fields_by_name['other_customer_number'].containing_oneof = _ADOPTCUSTOMERSTATECOMMAND.oneofs_by_name['other_customer']
_ADOPTCUSTOMERSTATECOMMAND.oneofs_by_name['other_customer'].fields.append(
  _ADOPTCUSTOMERSTATECOMMAND.fields_by_name['other_secondary_id'])
_ADOPTCUSTOMERSTATECOMMAND.fields_by_name['other_secondary_id'].containing_oneof = _ADOPTCUSTOMERSTATECOMMAND.oneofs_by_name['other_customer']
_ADDCUSTOMERREMINDERCOMMAND.fields_by_name['customer_number'].message_type = common__model__pb2._CUSTOMERNUMBER
_ADDCUSTOMERREMINDERCOMMAND.fields_by_name['secondary_id'].message_type = common__model__pb2._INDEXMAPPING
_ADDCUSTOMERREMINDERCOMMAND.fields_by_name['reminder'].message_type = app__model__pb2._CUSTOMERREMINDER
_ADDCUSTOMERREMINDERCOMMAND.oneofs_by_name['customer'].fields.append(
  _ADDCUSTOMERREMINDERCOMMAND.fields_by_name['customer_id'])
_ADDCUSTOMERREMINDERCOMMAND.fields_by_name['customer_id'].containing_oneof = _ADDCUSTOMERREMINDERCOMMAND.oneofs_by_name['customer']
_ADDCUSTOMERREMINDERCOMMAND.oneofs_by_name['customer'].fields.append(
  _ADDCUSTOMERREMINDERCOMMAND.fields_by_name['customer_number'])
_ADDCUSTOMERREMINDERCOMMAND.fields_by_name['customer_number'].containing_oneof = _ADDCUSTOMERREMINDERCOMMAND.oneofs_by_name['customer']
_ADDCUSTOMERREMINDERCOMMAND.oneofs_by_name['customer'].fields.append(
  _ADDCUSTOMERREMINDERCOMMAND.fields_by_name['secondary_id'])
_ADDCUSTOMERREMINDERCOMMAND.fields_by_name['secondary_id'].containing_oneof = _ADDCUSTOMERREMINDERCOMMAND.oneofs_by_name['customer']
_ADDCUSTOMERREMINDERTAGCOMMAND.fields_by_name['tag'].message_type = common__model__pb2._INDEXMAPPING
_ADDCUSTOMERREMINDERTAGCOMMAND.fields_by_name['reminder'].message_type = app__model__pb2._CUSTOMERREMINDER
_CANCELCUSTOMERREMINDERCOMMAND.fields_by_name['customer_number'].message_type = common__model__pb2._CUSTOMERNUMBER
_CANCELCUSTOMERREMINDERCOMMAND.fields_by_name['secondary_id'].message_type = common__model__pb2._INDEXMAPPING
_CANCELCUSTOMERREMINDERCOMMAND.oneofs_by_name['customer'].fields.append(
  _CANCELCUSTOMERREMINDERCOMMAND.fields_by_name['customer_id'])
_CANCELCUSTOMERREMINDERCOMMAND.fields_by_name['customer_id'].containing_oneof = _CANCELCUSTOMERREMINDERCOMMAND.oneofs_by_name['customer']
_CANCELCUSTOMERREMINDERCOMMAND.oneofs_by_name['customer'].fields.append(
  _CANCELCUSTOMERREMINDERCOMMAND.fields_by_name['customer_number'])
_CANCELCUSTOMERREMINDERCOMMAND.fields_by_name['customer_number'].containing_oneof = _CANCELCUSTOMERREMINDERCOMMAND.oneofs_by_name['customer']
_CANCELCUSTOMERREMINDERCOMMAND.oneofs_by_name['customer'].fields.append(
  _CANCELCUSTOMERREMINDERCOMMAND.fields_by_name['secondary_id'])
_CANCELCUSTOMERREMINDERCOMMAND.fields_by_name['secondary_id'].containing_oneof = _CANCELCUSTOMERREMINDERCOMMAND.oneofs_by_name['customer']
_CANCELCUSTOMERREMINDERTAGCOMMAND.fields_by_name['tag'].message_type = common__model__pb2._INDEXMAPPING
_UPDATECUSTOMERTAGCOMMAND.fields_by_name['customer_number'].message_type = common__model__pb2._CUSTOMERNUMBER
_UPDATECUSTOMERTAGCOMMAND.fields_by_name['secondary_id'].message_type = common__model__pb2._INDEXMAPPING
_UPDATECUSTOMERTAGCOMMAND.fields_by_name['updates'].message_type = common__model__pb2._CUSTOMERINDEX
_UPDATECUSTOMERTAGCOMMAND.oneofs_by_name['customer'].fields.append(
  _UPDATECUSTOMERTAGCOMMAND.fields_by_name['customer_id'])
_UPDATECUSTOMERTAGCOMMAND.fields_by_name['customer_id'].containing_oneof = _UPDATECUSTOMERTAGCOMMAND.oneofs_by_name['customer']
_UPDATECUSTOMERTAGCOMMAND.oneofs_by_name['customer'].fields.append(
  _UPDATECUSTOMERTAGCOMMAND.fields_by_name['customer_number'])
_UPDATECUSTOMERTAGCOMMAND.fields_by_name['customer_number'].containing_oneof = _UPDATECUSTOMERTAGCOMMAND.oneofs_by_name['customer']
_UPDATECUSTOMERTAGCOMMAND.oneofs_by_name['customer'].fields.append(
  _UPDATECUSTOMERTAGCOMMAND.fields_by_name['secondary_id'])
_UPDATECUSTOMERTAGCOMMAND.fields_by_name['secondary_id'].containing_oneof = _UPDATECUSTOMERTAGCOMMAND.oneofs_by_name['customer']
_DELETECUSTOMERTAGCOMMAND.fields_by_name['customer_number'].message_type = common__model__pb2._CUSTOMERNUMBER
_DELETECUSTOMERTAGCOMMAND.fields_by_name['secondary_id'].message_type = common__model__pb2._INDEXMAPPING
_DELETECUSTOMERTAGCOMMAND.oneofs_by_name['customer'].fields.append(
  _DELETECUSTOMERTAGCOMMAND.fields_by_name['customer_id'])
_DELETECUSTOMERTAGCOMMAND.fields_by_name['customer_id'].containing_oneof = _DELETECUSTOMERTAGCOMMAND.oneofs_by_name['customer']
_DELETECUSTOMERTAGCOMMAND.oneofs_by_name['customer'].fields.append(
  _DELETECUSTOMERTAGCOMMAND.fields_by_name['customer_number'])
_DELETECUSTOMERTAGCOMMAND.fields_by_name['customer_number'].containing_oneof = _DELETECUSTOMERTAGCOMMAND.oneofs_by_name['customer']
_DELETECUSTOMERTAGCOMMAND.oneofs_by_name['customer'].fields.append(
  _DELETECUSTOMERTAGCOMMAND.fields_by_name['secondary_id'])
_DELETECUSTOMERTAGCOMMAND.fields_by_name['secondary_id'].containing_oneof = _DELETECUSTOMERTAGCOMMAND.oneofs_by_name['customer']
_UPDATECUSTOMERSECONDARYIDCOMMAND.fields_by_name['customer_number'].message_type = common__model__pb2._CUSTOMERNUMBER
_UPDATECUSTOMERSECONDARYIDCOMMAND.fields_by_name['secondary_id'].message_type = common__model__pb2._INDEXMAPPING
_UPDATECUSTOMERSECONDARYIDCOMMAND.fields_by_name['updates'].message_type = common__model__pb2._CUSTOMERINDEX
_UPDATECUSTOMERSECONDARYIDCOMMAND.oneofs_by_name['customer'].fields.append(
  _UPDATECUSTOMERSECONDARYIDCOMMAND.fields_by_name['customer_id'])
_UPDATECUSTOMERSECONDARYIDCOMMAND.fields_by_name['customer_id'].containing_oneof = _UPDATECUSTOMERSECONDARYIDCOMMAND.oneofs_by_name['customer']
_UPDATECUSTOMERSECONDARYIDCOMMAND.oneofs_by_name['customer'].fields.append(
  _UPDATECUSTOMERSECONDARYIDCOMMAND.fields_by_name['customer_number'])
_UPDATECUSTOMERSECONDARYIDCOMMAND.fields_by_name['customer_number'].containing_oneof = _UPDATECUSTOMERSECONDARYIDCOMMAND.oneofs_by_name['customer']
_UPDATECUSTOMERSECONDARYIDCOMMAND.oneofs_by_name['customer'].fields.append(
  _UPDATECUSTOMERSECONDARYIDCOMMAND.fields_by_name['secondary_id'])
_UPDATECUSTOMERSECONDARYIDCOMMAND.fields_by_name['secondary_id'].containing_oneof = _UPDATECUSTOMERSECONDARYIDCOMMAND.oneofs_by_name['customer']
_DELETECUSTOMERSECONDARYIDCOMMAND.fields_by_name['customer_number'].message_type = common__model__pb2._CUSTOMERNUMBER
_DELETECUSTOMERSECONDARYIDCOMMAND.fields_by_name['secondary_id'].message_type = common__model__pb2._INDEXMAPPING
_DELETECUSTOMERSECONDARYIDCOMMAND.fields_by_name['deletions'].message_type = common__model__pb2._INDEXMAPPING
_DELETECUSTOMERSECONDARYIDCOMMAND.oneofs_by_name['customer'].fields.append(
  _DELETECUSTOMERSECONDARYIDCOMMAND.fields_by_name['customer_id'])
_DELETECUSTOMERSECONDARYIDCOMMAND.fields_by_name['customer_id'].containing_oneof = _DELETECUSTOMERSECONDARYIDCOMMAND.oneofs_by_name['customer']
_DELETECUSTOMERSECONDARYIDCOMMAND.oneofs_by_name['customer'].fields.append(
  _DELETECUSTOMERSECONDARYIDCOMMAND.fields_by_name['customer_number'])
_DELETECUSTOMERSECONDARYIDCOMMAND.fields_by_name['customer_number'].containing_oneof = _DELETECUSTOMERSECONDARYIDCOMMAND.oneofs_by_name['customer']
_DELETECUSTOMERSECONDARYIDCOMMAND.oneofs_by_name['customer'].fields.append(
  _DELETECUSTOMERSECONDARYIDCOMMAND.fields_by_name['secondary_id'])
_DELETECUSTOMERSECONDARYIDCOMMAND.fields_by_name['secondary_id'].containing_oneof = _DELETECUSTOMERSECONDARYIDCOMMAND.oneofs_by_name['customer']
_UPDATECUSTOMERMETADATACOMMAND_UPDATESENTRY.fields_by_name['value'].message_type = common__model__pb2._DATAMAPVALUE
_UPDATECUSTOMERMETADATACOMMAND_UPDATESENTRY.containing_type = _UPDATECUSTOMERMETADATACOMMAND
_UPDATECUSTOMERMETADATACOMMAND.fields_by_name['customer_number'].message_type = common__model__pb2._CUSTOMERNUMBER
_UPDATECUSTOMERMETADATACOMMAND.fields_by_name['secondary_id'].message_type = common__model__pb2._INDEXMAPPING
_UPDATECUSTOMERMETADATACOMMAND.fields_by_name['updates'].message_type = _UPDATECUSTOMERMETADATACOMMAND_UPDATESENTRY
_UPDATECUSTOMERMETADATACOMMAND.oneofs_by_name['customer'].fields.append(
  _UPDATECUSTOMERMETADATACOMMAND.fields_by_name['customer_id'])
_UPDATECUSTOMERMETADATACOMMAND.fields_by_name['customer_id'].containing_oneof = _UPDATECUSTOMERMETADATACOMMAND.oneofs_by_name['customer']
_UPDATECUSTOMERMETADATACOMMAND.oneofs_by_name['customer'].fields.append(
  _UPDATECUSTOMERMETADATACOMMAND.fields_by_name['customer_number'])
_UPDATECUSTOMERMETADATACOMMAND.fields_by_name['customer_number'].containing_oneof = _UPDATECUSTOMERMETADATACOMMAND.oneofs_by_name['customer']
_UPDATECUSTOMERMETADATACOMMAND.oneofs_by_name['customer'].fields.append(
  _UPDATECUSTOMERMETADATACOMMAND.fields_by_name['secondary_id'])
_UPDATECUSTOMERMETADATACOMMAND.fields_by_name['secondary_id'].containing_oneof = _UPDATECUSTOMERMETADATACOMMAND.oneofs_by_name['customer']
_DELETECUSTOMERMETADATACOMMAND.fields_by_name['customer_number'].message_type = common__model__pb2._CUSTOMERNUMBER
_DELETECUSTOMERMETADATACOMMAND.fields_by_name['secondary_id'].message_type = common__model__pb2._INDEXMAPPING
_DELETECUSTOMERMETADATACOMMAND.oneofs_by_name['customer'].fields.append(
  _DELETECUSTOMERMETADATACOMMAND.fields_by_name['customer_id'])
_DELETECUSTOMERMETADATACOMMAND.fields_by_name['customer_id'].containing_oneof = _DELETECUSTOMERMETADATACOMMAND.oneofs_by_name['customer']
_DELETECUSTOMERMETADATACOMMAND.oneofs_by_name['customer'].fields.append(
  _DELETECUSTOMERMETADATACOMMAND.fields_by_name['customer_number'])
_DELETECUSTOMERMETADATACOMMAND.fields_by_name['customer_number'].containing_oneof = _DELETECUSTOMERMETADATACOMMAND.oneofs_by_name['customer']
_DELETECUSTOMERMETADATACOMMAND.oneofs_by_name['customer'].fields.append(
  _DELETECUSTOMERMETADATACOMMAND.fields_by_name['secondary_id'])
_DELETECUSTOMERMETADATACOMMAND.fields_by_name['secondary_id'].containing_oneof = _DELETECUSTOMERMETADATACOMMAND.oneofs_by_name['customer']
_UPDATECUSTOMERSTATEREPLY.fields_by_name['customer_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_UPDATECUSTOMERAPPDATACOMMAND.fields_by_name['customer_number'].message_type = common__model__pb2._CUSTOMERNUMBER
_UPDATECUSTOMERAPPDATACOMMAND.fields_by_name['secondary_id'].message_type = common__model__pb2._INDEXMAPPING
_UPDATECUSTOMERAPPDATACOMMAND.fields_by_name['update'].message_type = common__model__pb2._DATAMAPVALUE
_UPDATECUSTOMERAPPDATACOMMAND.oneofs_by_name['customer'].fields.append(
  _UPDATECUSTOMERAPPDATACOMMAND.fields_by_name['customer_id'])
_UPDATECUSTOMERAPPDATACOMMAND.fields_by_name['customer_id'].containing_oneof = _UPDATECUSTOMERAPPDATACOMMAND.oneofs_by_name['customer']
_UPDATECUSTOMERAPPDATACOMMAND.oneofs_by_name['customer'].fields.append(
  _UPDATECUSTOMERAPPDATACOMMAND.fields_by_name['customer_number'])
_UPDATECUSTOMERAPPDATACOMMAND.fields_by_name['customer_number'].containing_oneof = _UPDATECUSTOMERAPPDATACOMMAND.oneofs_by_name['customer']
_UPDATECUSTOMERAPPDATACOMMAND.oneofs_by_name['customer'].fields.append(
  _UPDATECUSTOMERAPPDATACOMMAND.fields_by_name['secondary_id'])
_UPDATECUSTOMERAPPDATACOMMAND.fields_by_name['secondary_id'].containing_oneof = _UPDATECUSTOMERAPPDATACOMMAND.oneofs_by_name['customer']
_DELETECUSTOMERAPPDATACOMMAND.fields_by_name['customer_number'].message_type = common__model__pb2._CUSTOMERNUMBER
_DELETECUSTOMERAPPDATACOMMAND.fields_by_name['secondary_id'].message_type = common__model__pb2._INDEXMAPPING
_DELETECUSTOMERAPPDATACOMMAND.oneofs_by_name['customer'].fields.append(
  _DELETECUSTOMERAPPDATACOMMAND.fields_by_name['customer_id'])
_DELETECUSTOMERAPPDATACOMMAND.fields_by_name['customer_id'].containing_oneof = _DELETECUSTOMERAPPDATACOMMAND.oneofs_by_name['customer']
_DELETECUSTOMERAPPDATACOMMAND.oneofs_by_name['customer'].fields.append(
  _DELETECUSTOMERAPPDATACOMMAND.fields_by_name['customer_number'])
_DELETECUSTOMERAPPDATACOMMAND.fields_by_name['customer_number'].containing_oneof = _DELETECUSTOMERAPPDATACOMMAND.oneofs_by_name['customer']
_DELETECUSTOMERAPPDATACOMMAND.oneofs_by_name['customer'].fields.append(
  _DELETECUSTOMERAPPDATACOMMAND.fields_by_name['secondary_id'])
_DELETECUSTOMERAPPDATACOMMAND.fields_by_name['secondary_id'].containing_oneof = _DELETECUSTOMERAPPDATACOMMAND.oneofs_by_name['customer']
_UPDATECUSTOMERAPPDATAREPLY.fields_by_name['customer_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_LEASECUSTOMERAPPDATACOMMAND.fields_by_name['customer_number'].message_type = common__model__pb2._CUSTOMERNUMBER
_LEASECUSTOMERAPPDATACOMMAND.fields_by_name['secondary_id'].message_type = common__model__pb2._INDEXMAPPING
_LEASECUSTOMERAPPDATACOMMAND.oneofs_by_name['customer'].fields.append(
  _LEASECUSTOMERAPPDATACOMMAND.fields_by_name['customer_id'])
_LEASECUSTOMERAPPDATACOMMAND.fields_by_name['customer_id'].containing_oneof = _LEASECUSTOMERAPPDATACOMMAND.oneofs_by_name['customer']
_LEASECUSTOMERAPPDATACOMMAND.oneofs_by_name['customer'].fields.append(
  _LEASECUSTOMERAPPDATACOMMAND.fields_by_name['customer_number'])
_LEASECUSTOMERAPPDATACOMMAND.fields_by_name['customer_number'].containing_oneof = _LEASECUSTOMERAPPDATACOMMAND.oneofs_by_name['customer']
_LEASECUSTOMERAPPDATACOMMAND.oneofs_by_name['customer'].fields.append(
  _LEASECUSTOMERAPPDATACOMMAND.fields_by_name['secondary_id'])
_LEASECUSTOMERAPPDATACOMMAND.fields_by_name['secondary_id'].containing_oneof = _LEASECUSTOMERAPPDATACOMMAND.oneofs_by_name['customer']
_LEASECUSTOMERAPPDATAREPLY.fields_by_name['customer_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_LEASECUSTOMERAPPDATAREPLY.fields_by_name['value'].message_type = common__model__pb2._DATAMAPVALUE
_SENDMESSAGECOMMAND.fields_by_name['customer_number'].message_type = common__model__pb2._CUSTOMERNUMBER
_SENDMESSAGECOMMAND.fields_by_name['channel_number'].message_type = messaging__model__pb2._MESSAGINGCHANNELNUMBER
_SENDMESSAGECOMMAND.fields_by_name['message'].message_type = messaging__model__pb2._OUTBOUNDMESSAGE
_REPLYTOMESSAGECOMMAND.fields_by_name['message'].message_type = messaging__model__pb2._OUTBOUNDMESSAGE
_SENDMESSAGETAGCOMMAND.fields_by_name['tag'].message_type = common__model__pb2._INDEXMAPPING
_SENDMESSAGETAGCOMMAND.fields_by_name['channel_number'].message_type = messaging__model__pb2._MESSAGINGCHANNELNUMBER
_SENDMESSAGETAGCOMMAND.fields_by_name['message'].message_type = messaging__model__pb2._OUTBOUNDMESSAGE
_SENDMESSAGEREPLY.fields_by_name['status'].enum_type = messaging__model__pb2._MESSAGEDELIVERYSTATUS
_SENDMESSAGEREPLY.fields_by_name['message_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SENDMESSAGEREPLY.fields_by_name['session_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SENDMESSAGEREPLY.fields_by_name['customer_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_UPDATEMESSAGINGCONSENTCOMMAND.fields_by_name['customer_number'].message_type = common__model__pb2._CUSTOMERNUMBER
_UPDATEMESSAGINGCONSENTCOMMAND.fields_by_name['channel_number'].message_type = messaging__model__pb2._MESSAGINGCHANNELNUMBER
_UPDATEMESSAGINGCONSENTCOMMAND.fields_by_name['update'].enum_type = messaging__model__pb2._MESSAGINGCONSENTUPDATE
_UPDATEMESSAGINGCONSENTREPLY.fields_by_name['status'].enum_type = messaging__model__pb2._MESSAGINGCONSENTUPDATESTATUS
_UPDATEMESSAGINGCONSENTREPLY.fields_by_name['customer_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_INITIATEPAYMENTCOMMAND.fields_by_name['debit_party'].message_type = payment__model__pb2._PAYMENTCOUNTERPARTY
_INITIATEPAYMENTCOMMAND.fields_by_name['credit_party'].message_type = payment__model__pb2._PAYMENTCOUNTERPARTY
_INITIATEPAYMENTCOMMAND.fields_by_name['value'].message_type = common__model__pb2._CASH
_INITIATEPAYMENTREPLY.fields_by_name['status'].enum_type = payment__model__pb2._PAYMENTSTATUS
_INITIATEPAYMENTREPLY.fields_by_name['transaction_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_INITIATEPAYMENTREPLY.fields_by_name['debit_customer_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_INITIATEPAYMENTREPLY.fields_by_name['credit_customer_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_TAGCOMMANDREPLY.fields_by_name['work_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CUSTOMERACTIVITYCOMMAND_PROPERTIESENTRY.containing_type = _CUSTOMERACTIVITYCOMMAND
_CUSTOMERACTIVITYCOMMAND.fields_by_name['customer_number'].message_type = common__model__pb2._CUSTOMERNUMBER
_CUSTOMERACTIVITYCOMMAND.fields_by_name['channel_number'].message_type = activity__model__pb2._ACTIVITYCHANNELNUMBER
_CUSTOMERACTIVITYCOMMAND.fields_by_name['properties'].message_type = _CUSTOMERACTIVITYCOMMAND_PROPERTIESENTRY
_CUSTOMERACTIVITYREPLY.fields_by_name['customer_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SERVERTOAPPNOTIFICATION.fields_by_name['customer'].message_type = _SERVERTOAPPCUSTOMERNOTIFICATION
_SERVERTOAPPNOTIFICATION.fields_by_name['purse'].message_type = _SERVERTOAPPPURSENOTIFICATION
_SERVERTOAPPNOTIFICATION.oneofs_by_name['entry'].fields.append(
  _SERVERTOAPPNOTIFICATION.fields_by_name['customer'])
_SERVERTOAPPNOTIFICATION.fields_by_name['customer'].containing_oneof = _SERVERTOAPPNOTIFICATION.oneofs_by_name['entry']
_SERVERTOAPPNOTIFICATION.oneofs_by_name['entry'].fields.append(
  _SERVERTOAPPNOTIFICATION.fields_by_name['purse'])
_SERVERTOAPPNOTIFICATION.fields_by_name['purse'].containing_oneof = _SERVERTOAPPNOTIFICATION.oneofs_by_name['entry']
_SERVERTOAPPCUSTOMERNOTIFICATION.fields_by_name['app_data'].message_type = common__model__pb2._DATAMAPVALUE
_SERVERTOAPPCUSTOMERNOTIFICATION.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SERVERTOAPPCUSTOMERNOTIFICATION.fields_by_name['reminder'].message_type = _REMINDERNOTIFICATION
_SERVERTOAPPCUSTOMERNOTIFICATION.fields_by_name['messaging_session_started'].message_type = _MESSAGINGSESSIONSTARTEDNOTIFICATION
_SERVERTOAPPCUSTOMERNOTIFICATION.fields_by_name['messaging_session_renewed'].message_type = _MESSAGINGSESSIONRENEWEDNOTIFICATION
_SERVERTOAPPCUSTOMERNOTIFICATION.fields_by_name['messaging_session_ended'].message_type = _MESSAGINGSESSIONENDEDNOTIFICATION
_SERVERTOAPPCUSTOMERNOTIFICATION.fields_by_name['messaging_consent_update'].message_type = _MESSAGINGCONSENTUPDATENOTIFICATION
_SERVERTOAPPCUSTOMERNOTIFICATION.fields_by_name['received_message'].message_type = _RECEIVEDMESSAGENOTIFICATION
_SERVERTOAPPCUSTOMERNOTIFICATION.fields_by_name['message_status'].message_type = _MESSAGESTATUSNOTIFICATION
_SERVERTOAPPCUSTOMERNOTIFICATION.fields_by_name['sent_message_reaction'].message_type = _SENTMESSAGEREACTIONNOTIFICATION
_SERVERTOAPPCUSTOMERNOTIFICATION.fields_by_name['received_payment'].message_type = _RECEIVEDPAYMENTNOTIFICATION
_SERVERTOAPPCUSTOMERNOTIFICATION.fields_by_name['payment_status'].message_type = _PAYMENTSTATUSNOTIFICATION
_SERVERTOAPPCUSTOMERNOTIFICATION.fields_by_name['wallet_payment_status'].message_type = _WALLETPAYMENTSTATUSNOTIFICATION
_SERVERTOAPPCUSTOMERNOTIFICATION.fields_by_name['customer_activity'].message_type = _CUSTOMERACTIVITYNOTIFICATION
_SERVERTOAPPCUSTOMERNOTIFICATION.oneofs_by_name['entry'].fields.append(
  _SERVERTOAPPCUSTOMERNOTIFICATION.fields_by_name['reminder'])
_SERVERTOAPPCUSTOMERNOTIFICATION.fields_by_name['reminder'].containing_oneof = _SERVERTOAPPCUSTOMERNOTIFICATION.oneofs_by_name['entry']
_SERVERTOAPPCUSTOMERNOTIFICATION.oneofs_by_name['entry'].fields.append(
  _SERVERTOAPPCUSTOMERNOTIFICATION.fields_by_name['messaging_session_started'])
_SERVERTOAPPCUSTOMERNOTIFICATION.fields_by_name['messaging_session_started'].containing_oneof = _SERVERTOAPPCUSTOMERNOTIFICATION.oneofs_by_name['entry']
_SERVERTOAPPCUSTOMERNOTIFICATION.oneofs_by_name['entry'].fields.append(
  _SERVERTOAPPCUSTOMERNOTIFICATION.fields_by_name['messaging_session_renewed'])
_SERVERTOAPPCUSTOMERNOTIFICATION.fields_by_name['messaging_session_renewed'].containing_oneof = _SERVERTOAPPCUSTOMERNOTIFICATION.oneofs_by_name['entry']
_SERVERTOAPPCUSTOMERNOTIFICATION.oneofs_by_name['entry'].fields.append(
  _SERVERTOAPPCUSTOMERNOTIFICATION.fields_by_name['messaging_session_ended'])
_SERVERTOAPPCUSTOMERNOTIFICATION.fields_by_name['messaging_session_ended'].containing_oneof = _SERVERTOAPPCUSTOMERNOTIFICATION.oneofs_by_name['entry']
_SERVERTOAPPCUSTOMERNOTIFICATION.oneofs_by_name['entry'].fields.append(
  _SERVERTOAPPCUSTOMERNOTIFICATION.fields_by_name['messaging_consent_update'])
_SERVERTOAPPCUSTOMERNOTIFICATION.fields_by_name['messaging_consent_update'].containing_oneof = _SERVERTOAPPCUSTOMERNOTIFICATION.oneofs_by_name['entry']
_SERVERTOAPPCUSTOMERNOTIFICATION.oneofs_by_name['entry'].fields.append(
  _SERVERTOAPPCUSTOMERNOTIFICATION.fields_by_name['received_message'])
_SERVERTOAPPCUSTOMERNOTIFICATION.fields_by_name['received_message'].containing_oneof = _SERVERTOAPPCUSTOMERNOTIFICATION.oneofs_by_name['entry']
_SERVERTOAPPCUSTOMERNOTIFICATION.oneofs_by_name['entry'].fields.append(
  _SERVERTOAPPCUSTOMERNOTIFICATION.fields_by_name['message_status'])
_SERVERTOAPPCUSTOMERNOTIFICATION.fields_by_name['message_status'].containing_oneof = _SERVERTOAPPCUSTOMERNOTIFICATION.oneofs_by_name['entry']
_SERVERTOAPPCUSTOMERNOTIFICATION.oneofs_by_name['entry'].fields.append(
  _SERVERTOAPPCUSTOMERNOTIFICATION.fields_by_name['sent_message_reaction'])
_SERVERTOAPPCUSTOMERNOTIFICATION.fields_by_name['sent_message_reaction'].containing_oneof = _SERVERTOAPPCUSTOMERNOTIFICATION.oneofs_by_name['entry']
_SERVERTOAPPCUSTOMERNOTIFICATION.oneofs_by_name['entry'].fields.append(
  _SERVERTOAPPCUSTOMERNOTIFICATION.fields_by_name['received_payment'])
_SERVERTOAPPCUSTOMERNOTIFICATION.fields_by_name['received_payment'].containing_oneof = _SERVERTOAPPCUSTOMERNOTIFICATION.oneofs_by_name['entry']
_SERVERTOAPPCUSTOMERNOTIFICATION.oneofs_by_name['entry'].fields.append(
  _SERVERTOAPPCUSTOMERNOTIFICATION.fields_by_name['payment_status'])
_SERVERTOAPPCUSTOMERNOTIFICATION.fields_by_name['payment_status'].containing_oneof = _SERVERTOAPPCUSTOMERNOTIFICATION.oneofs_by_name['entry']
_SERVERTOAPPCUSTOMERNOTIFICATION.oneofs_by_name['entry'].fields.append(
  _SERVERTOAPPCUSTOMERNOTIFICATION.fields_by_name['wallet_payment_status'])
_SERVERTOAPPCUSTOMERNOTIFICATION.fields_by_name['wallet_payment_status'].containing_oneof = _SERVERTOAPPCUSTOMERNOTIFICATION.oneofs_by_name['entry']
_SERVERTOAPPCUSTOMERNOTIFICATION.oneofs_by_name['entry'].fields.append(
  _SERVERTOAPPCUSTOMERNOTIFICATION.fields_by_name['customer_activity'])
_SERVERTOAPPCUSTOMERNOTIFICATION.fields_by_name['customer_activity'].containing_oneof = _SERVERTOAPPCUSTOMERNOTIFICATION.oneofs_by_name['entry']
_SERVERTOAPPPURSENOTIFICATION.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SERVERTOAPPPURSENOTIFICATION.fields_by_name['payment_status'].message_type = _PAYMENTSTATUSNOTIFICATION
_SERVERTOAPPPURSENOTIFICATION.oneofs_by_name['entry'].fields.append(
  _SERVERTOAPPPURSENOTIFICATION.fields_by_name['payment_status'])
_SERVERTOAPPPURSENOTIFICATION.fields_by_name['payment_status'].containing_oneof = _SERVERTOAPPPURSENOTIFICATION.oneofs_by_name['entry']
_APPDATAUPDATE.fields_by_name['data'].message_type = common__model__pb2._DATAMAPVALUE
_SERVERTOAPPNOTIFICATIONREPLY.fields_by_name['data_update'].message_type = _APPDATAUPDATE
_SERVERTOAPPNOTIFICATIONREPLY.fields_by_name['message'].message_type = messaging__model__pb2._OUTBOUNDMESSAGE
_REMINDERNOTIFICATION.fields_by_name['reminder'].message_type = app__model__pb2._CUSTOMERREMINDER
_REMINDERNOTIFICATION.fields_by_name['tag'].message_type = common__model__pb2._CUSTOMERINDEX
_REMINDERNOTIFICATION.fields_by_name['work_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_MESSAGINGSESSIONSTARTEDNOTIFICATION.fields_by_name['customer_number'].message_type = common__model__pb2._CUSTOMERNUMBER
_MESSAGINGSESSIONSTARTEDNOTIFICATION.fields_by_name['channel_number'].message_type = messaging__model__pb2._MESSAGINGCHANNELNUMBER
_MESSAGINGSESSIONSTARTEDNOTIFICATION.fields_by_name['expires_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_MESSAGINGSESSIONRENEWEDNOTIFICATION.fields_by_name['customer_number'].message_type = common__model__pb2._CUSTOMERNUMBER
_MESSAGINGSESSIONRENEWEDNOTIFICATION.fields_by_name['channel_number'].message_type = messaging__model__pb2._MESSAGINGCHANNELNUMBER
_MESSAGINGSESSIONRENEWEDNOTIFICATION.fields_by_name['expires_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_MESSAGINGSESSIONENDEDNOTIFICATION.fields_by_name['customer_number'].message_type = common__model__pb2._CUSTOMERNUMBER
_MESSAGINGSESSIONENDEDNOTIFICATION.fields_by_name['channel_number'].message_type = messaging__model__pb2._MESSAGINGCHANNELNUMBER
_MESSAGINGSESSIONENDEDNOTIFICATION.fields_by_name['duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_MESSAGINGSESSIONENDEDNOTIFICATION.fields_by_name['reason'].enum_type = messaging__model__pb2._MESSAGINGSESSIONENDREASON
_MESSAGINGCONSENTUPDATENOTIFICATION.fields_by_name['customer_number'].message_type = common__model__pb2._CUSTOMERNUMBER
_MESSAGINGCONSENTUPDATENOTIFICATION.fields_by_name['channel_number'].message_type = messaging__model__pb2._MESSAGINGCHANNELNUMBER
_MESSAGINGCONSENTUPDATENOTIFICATION.fields_by_name['update'].enum_type = messaging__model__pb2._MESSAGINGCONSENTUPDATE
_MESSAGINGCONSENTUPDATENOTIFICATION.fields_by_name['status'].enum_type = messaging__model__pb2._MESSAGINGCONSENTUPDATESTATUS
_RECEIVEDMESSAGENOTIFICATION.fields_by_name['customer_number'].message_type = common__model__pb2._CUSTOMERNUMBER
_RECEIVEDMESSAGENOTIFICATION.fields_by_name['channel_number'].message_type = messaging__model__pb2._MESSAGINGCHANNELNUMBER
_RECEIVEDMESSAGENOTIFICATION.fields_by_name['parts'].message_type = messaging__model__pb2._INBOUNDMESSAGEBODY
_RECEIVEDMESSAGENOTIFICATION.fields_by_name['session_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RECEIVEDMESSAGENOTIFICATION.fields_by_name['in_reply_to'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_MESSAGESTATUSNOTIFICATION.fields_by_name['status'].enum_type = messaging__model__pb2._MESSAGEDELIVERYSTATUS
_SENTMESSAGEREACTIONNOTIFICATION.fields_by_name['customer_number'].message_type = common__model__pb2._CUSTOMERNUMBER
_SENTMESSAGEREACTIONNOTIFICATION.fields_by_name['channel_number'].message_type = messaging__model__pb2._MESSAGINGCHANNELNUMBER
_SENTMESSAGEREACTIONNOTIFICATION.fields_by_name['reaction'].enum_type = messaging__model__pb2._MESSAGEREACTION
_RECEIVEDPAYMENTNOTIFICATION.fields_by_name['customer_number'].message_type = common__model__pb2._CUSTOMERNUMBER
_RECEIVEDPAYMENTNOTIFICATION.fields_by_name['channel_number'].message_type = payment__model__pb2._PAYMENTCHANNELNUMBER
_RECEIVEDPAYMENTNOTIFICATION.fields_by_name['value'].message_type = common__model__pb2._CASH
_RECEIVEDPAYMENTNOTIFICATION.fields_by_name['status'].enum_type = payment__model__pb2._PAYMENTSTATUS
_PAYMENTSTATUSNOTIFICATION.fields_by_name['status'].enum_type = payment__model__pb2._PAYMENTSTATUS
_WALLETPAYMENTSTATUSNOTIFICATION.fields_by_name['status'].enum_type = payment__model__pb2._PAYMENTSTATUS
_CUSTOMERACTIVITYNOTIFICATION.fields_by_name['customer_number'].message_type = common__model__pb2._CUSTOMERNUMBER
_CUSTOMERACTIVITYNOTIFICATION.fields_by_name['channel_number'].message_type = activity__model__pb2._ACTIVITYCHANNELNUMBER
_CUSTOMERACTIVITYNOTIFICATION.fields_by_name['activity'].message_type = activity__model__pb2._CUSTOMERACTIVITY
DESCRIPTOR.message_types_by_name['AppConnectionMetadata'] = _APPCONNECTIONMETADATA
DESCRIPTOR.message_types_by_name['AppToServerCommand'] = _APPTOSERVERCOMMAND
DESCRIPTOR.message_types_by_name['AppToServerCommandReply'] = _APPTOSERVERCOMMANDREPLY
DESCRIPTOR.message_types_by_name['GenerateAuthTokenCommand'] = _GENERATEAUTHTOKENCOMMAND
DESCRIPTOR.message_types_by_name['GenerateAuthTokenReply'] = _GENERATEAUTHTOKENREPLY
DESCRIPTOR.message_types_by_name['GetCustomerStateCommand'] = _GETCUSTOMERSTATECOMMAND
DESCRIPTOR.message_types_by_name['GetCustomerStateReply'] = _GETCUSTOMERSTATEREPLY
DESCRIPTOR.message_types_by_name['CustomerStateReplyData'] = _CUSTOMERSTATEREPLYDATA
DESCRIPTOR.message_types_by_name['AdoptCustomerStateCommand'] = _ADOPTCUSTOMERSTATECOMMAND
DESCRIPTOR.message_types_by_name['AddCustomerReminderCommand'] = _ADDCUSTOMERREMINDERCOMMAND
DESCRIPTOR.message_types_by_name['AddCustomerReminderTagCommand'] = _ADDCUSTOMERREMINDERTAGCOMMAND
DESCRIPTOR.message_types_by_name['CancelCustomerReminderCommand'] = _CANCELCUSTOMERREMINDERCOMMAND
DESCRIPTOR.message_types_by_name['CancelCustomerReminderTagCommand'] = _CANCELCUSTOMERREMINDERTAGCOMMAND
DESCRIPTOR.message_types_by_name['UpdateCustomerTagCommand'] = _UPDATECUSTOMERTAGCOMMAND
DESCRIPTOR.message_types_by_name['DeleteCustomerTagCommand'] = _DELETECUSTOMERTAGCOMMAND
DESCRIPTOR.message_types_by_name['UpdateCustomerSecondaryIdCommand'] = _UPDATECUSTOMERSECONDARYIDCOMMAND
DESCRIPTOR.message_types_by_name['DeleteCustomerSecondaryIdCommand'] = _DELETECUSTOMERSECONDARYIDCOMMAND
DESCRIPTOR.message_types_by_name['UpdateCustomerMetadataCommand'] = _UPDATECUSTOMERMETADATACOMMAND
DESCRIPTOR.message_types_by_name['DeleteCustomerMetadataCommand'] = _DELETECUSTOMERMETADATACOMMAND
DESCRIPTOR.message_types_by_name['UpdateCustomerStateReply'] = _UPDATECUSTOMERSTATEREPLY
DESCRIPTOR.message_types_by_name['UpdateCustomerAppDataCommand'] = _UPDATECUSTOMERAPPDATACOMMAND
DESCRIPTOR.message_types_by_name['DeleteCustomerAppDataCommand'] = _DELETECUSTOMERAPPDATACOMMAND
DESCRIPTOR.message_types_by_name['UpdateCustomerAppDataReply'] = _UPDATECUSTOMERAPPDATAREPLY
DESCRIPTOR.message_types_by_name['LeaseCustomerAppDataCommand'] = _LEASECUSTOMERAPPDATACOMMAND
DESCRIPTOR.message_types_by_name['LeaseCustomerAppDataReply'] = _LEASECUSTOMERAPPDATAREPLY
DESCRIPTOR.message_types_by_name['SendMessageCommand'] = _SENDMESSAGECOMMAND
DESCRIPTOR.message_types_by_name['ReplyToMessageCommand'] = _REPLYTOMESSAGECOMMAND
DESCRIPTOR.message_types_by_name['SendMessageTagCommand'] = _SENDMESSAGETAGCOMMAND
DESCRIPTOR.message_types_by_name['SendMessageReply'] = _SENDMESSAGEREPLY
DESCRIPTOR.message_types_by_name['UpdateMessagingConsentCommand'] = _UPDATEMESSAGINGCONSENTCOMMAND
DESCRIPTOR.message_types_by_name['UpdateMessagingConsentReply'] = _UPDATEMESSAGINGCONSENTREPLY
DESCRIPTOR.message_types_by_name['InitiatePaymentCommand'] = _INITIATEPAYMENTCOMMAND
DESCRIPTOR.message_types_by_name['InitiatePaymentReply'] = _INITIATEPAYMENTREPLY
DESCRIPTOR.message_types_by_name['TagCommandReply'] = _TAGCOMMANDREPLY
DESCRIPTOR.message_types_by_name['CustomerActivityCommand'] = _CUSTOMERACTIVITYCOMMAND
DESCRIPTOR.message_types_by_name['CustomerActivityReply'] = _CUSTOMERACTIVITYREPLY
DESCRIPTOR.message_types_by_name['ServerToAppNotification'] = _SERVERTOAPPNOTIFICATION
DESCRIPTOR.message_types_by_name['ServerToAppCustomerNotification'] = _SERVERTOAPPCUSTOMERNOTIFICATION
DESCRIPTOR.message_types_by_name['ServerToAppPurseNotification'] = _SERVERTOAPPPURSENOTIFICATION
DESCRIPTOR.message_types_by_name['AppDataUpdate'] = _APPDATAUPDATE
DESCRIPTOR.message_types_by_name['ServerToAppNotificationReply'] = _SERVERTOAPPNOTIFICATIONREPLY
DESCRIPTOR.message_types_by_name['ReminderNotification'] = _REMINDERNOTIFICATION
DESCRIPTOR.message_types_by_name['MessagingSessionStartedNotification'] = _MESSAGINGSESSIONSTARTEDNOTIFICATION
DESCRIPTOR.message_types_by_name['MessagingSessionRenewedNotification'] = _MESSAGINGSESSIONRENEWEDNOTIFICATION
DESCRIPTOR.message_types_by_name['MessagingSessionEndedNotification'] = _MESSAGINGSESSIONENDEDNOTIFICATION
DESCRIPTOR.message_types_by_name['MessagingConsentUpdateNotification'] = _MESSAGINGCONSENTUPDATENOTIFICATION
DESCRIPTOR.message_types_by_name['ReceivedMessageNotification'] = _RECEIVEDMESSAGENOTIFICATION
DESCRIPTOR.message_types_by_name['MessageStatusNotification'] = _MESSAGESTATUSNOTIFICATION
DESCRIPTOR.message_types_by_name['SentMessageReactionNotification'] = _SENTMESSAGEREACTIONNOTIFICATION
DESCRIPTOR.message_types_by_name['ReceivedPaymentNotification'] = _RECEIVEDPAYMENTNOTIFICATION
DESCRIPTOR.message_types_by_name['PaymentStatusNotification'] = _PAYMENTSTATUSNOTIFICATION
DESCRIPTOR.message_types_by_name['WalletPaymentStatusNotification'] = _WALLETPAYMENTSTATUSNOTIFICATION
DESCRIPTOR.message_types_by_name['CustomerActivityNotification'] = _CUSTOMERACTIVITYNOTIFICATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AppConnectionMetadata = _reflection.GeneratedProtocolMessageType('AppConnectionMetadata', (_message.Message,), {
  'DESCRIPTOR' : _APPCONNECTIONMETADATA,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.AppConnectionMetadata)
  })
_sym_db.RegisterMessage(AppConnectionMetadata)

AppToServerCommand = _reflection.GeneratedProtocolMessageType('AppToServerCommand', (_message.Message,), {
  'DESCRIPTOR' : _APPTOSERVERCOMMAND,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.AppToServerCommand)
  })
_sym_db.RegisterMessage(AppToServerCommand)

AppToServerCommandReply = _reflection.GeneratedProtocolMessageType('AppToServerCommandReply', (_message.Message,), {
  'DESCRIPTOR' : _APPTOSERVERCOMMANDREPLY,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.AppToServerCommandReply)
  })
_sym_db.RegisterMessage(AppToServerCommandReply)

GenerateAuthTokenCommand = _reflection.GeneratedProtocolMessageType('GenerateAuthTokenCommand', (_message.Message,), {
  'DESCRIPTOR' : _GENERATEAUTHTOKENCOMMAND,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.GenerateAuthTokenCommand)
  })
_sym_db.RegisterMessage(GenerateAuthTokenCommand)

GenerateAuthTokenReply = _reflection.GeneratedProtocolMessageType('GenerateAuthTokenReply', (_message.Message,), {
  'DESCRIPTOR' : _GENERATEAUTHTOKENREPLY,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.GenerateAuthTokenReply)
  })
_sym_db.RegisterMessage(GenerateAuthTokenReply)

GetCustomerStateCommand = _reflection.GeneratedProtocolMessageType('GetCustomerStateCommand', (_message.Message,), {
  'DESCRIPTOR' : _GETCUSTOMERSTATECOMMAND,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.GetCustomerStateCommand)
  })
_sym_db.RegisterMessage(GetCustomerStateCommand)

GetCustomerStateReply = _reflection.GeneratedProtocolMessageType('GetCustomerStateReply', (_message.Message,), {
  'DESCRIPTOR' : _GETCUSTOMERSTATEREPLY,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.GetCustomerStateReply)
  })
_sym_db.RegisterMessage(GetCustomerStateReply)

CustomerStateReplyData = _reflection.GeneratedProtocolMessageType('CustomerStateReplyData', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMERSTATEREPLYDATA,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.CustomerStateReplyData)
  })
_sym_db.RegisterMessage(CustomerStateReplyData)

AdoptCustomerStateCommand = _reflection.GeneratedProtocolMessageType('AdoptCustomerStateCommand', (_message.Message,), {
  'DESCRIPTOR' : _ADOPTCUSTOMERSTATECOMMAND,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.AdoptCustomerStateCommand)
  })
_sym_db.RegisterMessage(AdoptCustomerStateCommand)

AddCustomerReminderCommand = _reflection.GeneratedProtocolMessageType('AddCustomerReminderCommand', (_message.Message,), {
  'DESCRIPTOR' : _ADDCUSTOMERREMINDERCOMMAND,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.AddCustomerReminderCommand)
  })
_sym_db.RegisterMessage(AddCustomerReminderCommand)

AddCustomerReminderTagCommand = _reflection.GeneratedProtocolMessageType('AddCustomerReminderTagCommand', (_message.Message,), {
  'DESCRIPTOR' : _ADDCUSTOMERREMINDERTAGCOMMAND,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.AddCustomerReminderTagCommand)
  })
_sym_db.RegisterMessage(AddCustomerReminderTagCommand)

CancelCustomerReminderCommand = _reflection.GeneratedProtocolMessageType('CancelCustomerReminderCommand', (_message.Message,), {
  'DESCRIPTOR' : _CANCELCUSTOMERREMINDERCOMMAND,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.CancelCustomerReminderCommand)
  })
_sym_db.RegisterMessage(CancelCustomerReminderCommand)

CancelCustomerReminderTagCommand = _reflection.GeneratedProtocolMessageType('CancelCustomerReminderTagCommand', (_message.Message,), {
  'DESCRIPTOR' : _CANCELCUSTOMERREMINDERTAGCOMMAND,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.CancelCustomerReminderTagCommand)
  })
_sym_db.RegisterMessage(CancelCustomerReminderTagCommand)

UpdateCustomerTagCommand = _reflection.GeneratedProtocolMessageType('UpdateCustomerTagCommand', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECUSTOMERTAGCOMMAND,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.UpdateCustomerTagCommand)
  })
_sym_db.RegisterMessage(UpdateCustomerTagCommand)

DeleteCustomerTagCommand = _reflection.GeneratedProtocolMessageType('DeleteCustomerTagCommand', (_message.Message,), {
  'DESCRIPTOR' : _DELETECUSTOMERTAGCOMMAND,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.DeleteCustomerTagCommand)
  })
_sym_db.RegisterMessage(DeleteCustomerTagCommand)

UpdateCustomerSecondaryIdCommand = _reflection.GeneratedProtocolMessageType('UpdateCustomerSecondaryIdCommand', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECUSTOMERSECONDARYIDCOMMAND,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.UpdateCustomerSecondaryIdCommand)
  })
_sym_db.RegisterMessage(UpdateCustomerSecondaryIdCommand)

DeleteCustomerSecondaryIdCommand = _reflection.GeneratedProtocolMessageType('DeleteCustomerSecondaryIdCommand', (_message.Message,), {
  'DESCRIPTOR' : _DELETECUSTOMERSECONDARYIDCOMMAND,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.DeleteCustomerSecondaryIdCommand)
  })
_sym_db.RegisterMessage(DeleteCustomerSecondaryIdCommand)

UpdateCustomerMetadataCommand = _reflection.GeneratedProtocolMessageType('UpdateCustomerMetadataCommand', (_message.Message,), {

  'UpdatesEntry' : _reflection.GeneratedProtocolMessageType('UpdatesEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATECUSTOMERMETADATACOMMAND_UPDATESENTRY,
    '__module__' : 'app_socket_pb2'
    # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.UpdateCustomerMetadataCommand.UpdatesEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATECUSTOMERMETADATACOMMAND,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.UpdateCustomerMetadataCommand)
  })
_sym_db.RegisterMessage(UpdateCustomerMetadataCommand)
_sym_db.RegisterMessage(UpdateCustomerMetadataCommand.UpdatesEntry)

DeleteCustomerMetadataCommand = _reflection.GeneratedProtocolMessageType('DeleteCustomerMetadataCommand', (_message.Message,), {
  'DESCRIPTOR' : _DELETECUSTOMERMETADATACOMMAND,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.DeleteCustomerMetadataCommand)
  })
_sym_db.RegisterMessage(DeleteCustomerMetadataCommand)

UpdateCustomerStateReply = _reflection.GeneratedProtocolMessageType('UpdateCustomerStateReply', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECUSTOMERSTATEREPLY,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.UpdateCustomerStateReply)
  })
_sym_db.RegisterMessage(UpdateCustomerStateReply)

UpdateCustomerAppDataCommand = _reflection.GeneratedProtocolMessageType('UpdateCustomerAppDataCommand', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECUSTOMERAPPDATACOMMAND,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.UpdateCustomerAppDataCommand)
  })
_sym_db.RegisterMessage(UpdateCustomerAppDataCommand)

DeleteCustomerAppDataCommand = _reflection.GeneratedProtocolMessageType('DeleteCustomerAppDataCommand', (_message.Message,), {
  'DESCRIPTOR' : _DELETECUSTOMERAPPDATACOMMAND,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.DeleteCustomerAppDataCommand)
  })
_sym_db.RegisterMessage(DeleteCustomerAppDataCommand)

UpdateCustomerAppDataReply = _reflection.GeneratedProtocolMessageType('UpdateCustomerAppDataReply', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECUSTOMERAPPDATAREPLY,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.UpdateCustomerAppDataReply)
  })
_sym_db.RegisterMessage(UpdateCustomerAppDataReply)

LeaseCustomerAppDataCommand = _reflection.GeneratedProtocolMessageType('LeaseCustomerAppDataCommand', (_message.Message,), {
  'DESCRIPTOR' : _LEASECUSTOMERAPPDATACOMMAND,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.LeaseCustomerAppDataCommand)
  })
_sym_db.RegisterMessage(LeaseCustomerAppDataCommand)

LeaseCustomerAppDataReply = _reflection.GeneratedProtocolMessageType('LeaseCustomerAppDataReply', (_message.Message,), {
  'DESCRIPTOR' : _LEASECUSTOMERAPPDATAREPLY,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.LeaseCustomerAppDataReply)
  })
_sym_db.RegisterMessage(LeaseCustomerAppDataReply)

SendMessageCommand = _reflection.GeneratedProtocolMessageType('SendMessageCommand', (_message.Message,), {
  'DESCRIPTOR' : _SENDMESSAGECOMMAND,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.SendMessageCommand)
  })
_sym_db.RegisterMessage(SendMessageCommand)

ReplyToMessageCommand = _reflection.GeneratedProtocolMessageType('ReplyToMessageCommand', (_message.Message,), {
  'DESCRIPTOR' : _REPLYTOMESSAGECOMMAND,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.ReplyToMessageCommand)
  })
_sym_db.RegisterMessage(ReplyToMessageCommand)

SendMessageTagCommand = _reflection.GeneratedProtocolMessageType('SendMessageTagCommand', (_message.Message,), {
  'DESCRIPTOR' : _SENDMESSAGETAGCOMMAND,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.SendMessageTagCommand)
  })
_sym_db.RegisterMessage(SendMessageTagCommand)

SendMessageReply = _reflection.GeneratedProtocolMessageType('SendMessageReply', (_message.Message,), {
  'DESCRIPTOR' : _SENDMESSAGEREPLY,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.SendMessageReply)
  })
_sym_db.RegisterMessage(SendMessageReply)

UpdateMessagingConsentCommand = _reflection.GeneratedProtocolMessageType('UpdateMessagingConsentCommand', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMESSAGINGCONSENTCOMMAND,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.UpdateMessagingConsentCommand)
  })
_sym_db.RegisterMessage(UpdateMessagingConsentCommand)

UpdateMessagingConsentReply = _reflection.GeneratedProtocolMessageType('UpdateMessagingConsentReply', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMESSAGINGCONSENTREPLY,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.UpdateMessagingConsentReply)
  })
_sym_db.RegisterMessage(UpdateMessagingConsentReply)

InitiatePaymentCommand = _reflection.GeneratedProtocolMessageType('InitiatePaymentCommand', (_message.Message,), {
  'DESCRIPTOR' : _INITIATEPAYMENTCOMMAND,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.InitiatePaymentCommand)
  })
_sym_db.RegisterMessage(InitiatePaymentCommand)

InitiatePaymentReply = _reflection.GeneratedProtocolMessageType('InitiatePaymentReply', (_message.Message,), {
  'DESCRIPTOR' : _INITIATEPAYMENTREPLY,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.InitiatePaymentReply)
  })
_sym_db.RegisterMessage(InitiatePaymentReply)

TagCommandReply = _reflection.GeneratedProtocolMessageType('TagCommandReply', (_message.Message,), {
  'DESCRIPTOR' : _TAGCOMMANDREPLY,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.TagCommandReply)
  })
_sym_db.RegisterMessage(TagCommandReply)

CustomerActivityCommand = _reflection.GeneratedProtocolMessageType('CustomerActivityCommand', (_message.Message,), {

  'PropertiesEntry' : _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _CUSTOMERACTIVITYCOMMAND_PROPERTIESENTRY,
    '__module__' : 'app_socket_pb2'
    # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.CustomerActivityCommand.PropertiesEntry)
    })
  ,
  'DESCRIPTOR' : _CUSTOMERACTIVITYCOMMAND,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.CustomerActivityCommand)
  })
_sym_db.RegisterMessage(CustomerActivityCommand)
_sym_db.RegisterMessage(CustomerActivityCommand.PropertiesEntry)

CustomerActivityReply = _reflection.GeneratedProtocolMessageType('CustomerActivityReply', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMERACTIVITYREPLY,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.CustomerActivityReply)
  })
_sym_db.RegisterMessage(CustomerActivityReply)

ServerToAppNotification = _reflection.GeneratedProtocolMessageType('ServerToAppNotification', (_message.Message,), {
  'DESCRIPTOR' : _SERVERTOAPPNOTIFICATION,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.ServerToAppNotification)
  })
_sym_db.RegisterMessage(ServerToAppNotification)

ServerToAppCustomerNotification = _reflection.GeneratedProtocolMessageType('ServerToAppCustomerNotification', (_message.Message,), {
  'DESCRIPTOR' : _SERVERTOAPPCUSTOMERNOTIFICATION,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.ServerToAppCustomerNotification)
  })
_sym_db.RegisterMessage(ServerToAppCustomerNotification)

ServerToAppPurseNotification = _reflection.GeneratedProtocolMessageType('ServerToAppPurseNotification', (_message.Message,), {
  'DESCRIPTOR' : _SERVERTOAPPPURSENOTIFICATION,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.ServerToAppPurseNotification)
  })
_sym_db.RegisterMessage(ServerToAppPurseNotification)

AppDataUpdate = _reflection.GeneratedProtocolMessageType('AppDataUpdate', (_message.Message,), {
  'DESCRIPTOR' : _APPDATAUPDATE,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.AppDataUpdate)
  })
_sym_db.RegisterMessage(AppDataUpdate)

ServerToAppNotificationReply = _reflection.GeneratedProtocolMessageType('ServerToAppNotificationReply', (_message.Message,), {
  'DESCRIPTOR' : _SERVERTOAPPNOTIFICATIONREPLY,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.ServerToAppNotificationReply)
  })
_sym_db.RegisterMessage(ServerToAppNotificationReply)

ReminderNotification = _reflection.GeneratedProtocolMessageType('ReminderNotification', (_message.Message,), {
  'DESCRIPTOR' : _REMINDERNOTIFICATION,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.ReminderNotification)
  })
_sym_db.RegisterMessage(ReminderNotification)

MessagingSessionStartedNotification = _reflection.GeneratedProtocolMessageType('MessagingSessionStartedNotification', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGINGSESSIONSTARTEDNOTIFICATION,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.MessagingSessionStartedNotification)
  })
_sym_db.RegisterMessage(MessagingSessionStartedNotification)

MessagingSessionRenewedNotification = _reflection.GeneratedProtocolMessageType('MessagingSessionRenewedNotification', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGINGSESSIONRENEWEDNOTIFICATION,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.MessagingSessionRenewedNotification)
  })
_sym_db.RegisterMessage(MessagingSessionRenewedNotification)

MessagingSessionEndedNotification = _reflection.GeneratedProtocolMessageType('MessagingSessionEndedNotification', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGINGSESSIONENDEDNOTIFICATION,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.MessagingSessionEndedNotification)
  })
_sym_db.RegisterMessage(MessagingSessionEndedNotification)

MessagingConsentUpdateNotification = _reflection.GeneratedProtocolMessageType('MessagingConsentUpdateNotification', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGINGCONSENTUPDATENOTIFICATION,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.MessagingConsentUpdateNotification)
  })
_sym_db.RegisterMessage(MessagingConsentUpdateNotification)

ReceivedMessageNotification = _reflection.GeneratedProtocolMessageType('ReceivedMessageNotification', (_message.Message,), {
  'DESCRIPTOR' : _RECEIVEDMESSAGENOTIFICATION,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.ReceivedMessageNotification)
  })
_sym_db.RegisterMessage(ReceivedMessageNotification)

MessageStatusNotification = _reflection.GeneratedProtocolMessageType('MessageStatusNotification', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGESTATUSNOTIFICATION,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.MessageStatusNotification)
  })
_sym_db.RegisterMessage(MessageStatusNotification)

SentMessageReactionNotification = _reflection.GeneratedProtocolMessageType('SentMessageReactionNotification', (_message.Message,), {
  'DESCRIPTOR' : _SENTMESSAGEREACTIONNOTIFICATION,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.SentMessageReactionNotification)
  })
_sym_db.RegisterMessage(SentMessageReactionNotification)

ReceivedPaymentNotification = _reflection.GeneratedProtocolMessageType('ReceivedPaymentNotification', (_message.Message,), {
  'DESCRIPTOR' : _RECEIVEDPAYMENTNOTIFICATION,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.ReceivedPaymentNotification)
  })
_sym_db.RegisterMessage(ReceivedPaymentNotification)

PaymentStatusNotification = _reflection.GeneratedProtocolMessageType('PaymentStatusNotification', (_message.Message,), {
  'DESCRIPTOR' : _PAYMENTSTATUSNOTIFICATION,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.PaymentStatusNotification)
  })
_sym_db.RegisterMessage(PaymentStatusNotification)

WalletPaymentStatusNotification = _reflection.GeneratedProtocolMessageType('WalletPaymentStatusNotification', (_message.Message,), {
  'DESCRIPTOR' : _WALLETPAYMENTSTATUSNOTIFICATION,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.WalletPaymentStatusNotification)
  })
_sym_db.RegisterMessage(WalletPaymentStatusNotification)

CustomerActivityNotification = _reflection.GeneratedProtocolMessageType('CustomerActivityNotification', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMERACTIVITYNOTIFICATION,
  '__module__' : 'app_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.CustomerActivityNotification)
  })
_sym_db.RegisterMessage(CustomerActivityNotification)


_UPDATECUSTOMERMETADATACOMMAND_UPDATESENTRY._options = None
_CUSTOMERACTIVITYCOMMAND_PROPERTIESENTRY._options = None
# @@protoc_insertion_point(module_scope)
